@@ -23,20 +23,20 @@ import java.lang.reflect.Modifier;
 import java.util.Collection;
 import java.util.Comparator;
 import java.util.HashSet;
+import java.util.Objects;
 import java.util.Set;
 
 import org.apache.commons.lang3.ArraySorter;
 import org.apache.commons.lang3.ArrayUtils;
+import org.apache.commons.lang3.ObjectUtils;
 import org.apache.commons.lang3.Validate;
 
 /**
- * <p>
  * Assists in implementing {@link Object#hashCode()} methods.
- * </p>
  *
  * <p>
  * This class enables a good {@code hashCode} method to be built for any class. It follows the rules laid out in
- * the book <a href="http://www.oracle.com/technetwork/java/effectivejava-136174.html">Effective Java</a> by Joshua Bloch. Writing a
+ * the book <a href="https://www.oracle.com/technetwork/java/effectivejava-136174.html">Effective Java</a> by Joshua Bloch. Writing a
  * good {@code hashCode} method is actually quite difficult. This class aims to simplify the process.
  * </p>
  *
@@ -114,9 +114,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     private static final int DEFAULT_MULTIPLIER_VALUE = 37;
 
     /**
-     * <p>
      * A registry of objects used by reflection methods to detect cyclical object references and avoid infinite loops.
-     * </p>
      *
      * @since 2.3
      */
@@ -140,9 +138,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      */
 
     /**
-     * <p>
      * Returns the registry of objects being traversed by the reflection methods in the current thread.
-     * </p>
      *
      * @return Set the registry of objects being traversed
      * @since 2.3
@@ -152,10 +148,8 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Returns {@code true} if the registry contains the given object. Used by the reflection methods to avoid
      * infinite loops.
-     * </p>
      *
      * @param value
      *            The object to lookup in the registry.
@@ -168,9 +162,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
-     * Appends the fields and values defined by the given object of the given {@code Class}.
-     * </p>
+     * Appends the fields and values defined by the given object of the given {@link Class}.
      *
      * @param object
      *            the object to append details of
@@ -199,14 +191,7 @@ public class HashCodeBuilder implements Builder<Integer> {
                     && (useTransients || !Modifier.isTransient(field.getModifiers()))
                     && !Modifier.isStatic(field.getModifiers())
                     && !field.isAnnotationPresent(HashCodeExclude.class)) {
-                    try {
-                        final Object fieldValue = field.get(object);
-                        builder.append(fieldValue);
-                    } catch (final IllegalAccessException e) {
-                        // this can't happen. Would get a Security exception instead
-                        // throw a runtime exception in case the impossible happens.
-                        throw new InternalError("Unexpected IllegalAccessException");
-                    }
+                    builder.append(Reflection.getUnchecked(field, object));
                 }
             }
         } finally {
@@ -215,9 +200,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * It uses {@code AccessibleObject.setAccessible} to gain access to private fields. This means that it will
@@ -227,7 +210,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      *
      * <p>
      * Transient members will be not be used, as they are likely derived fields, and not part of the value of the
-     * {@code Object}.
+     * {@link Object}.
      * </p>
      *
      * <p>
@@ -247,7 +230,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param object
      *            the Object to create a {@code hashCode} for
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the Object is {@code null}
      * @throws IllegalArgumentException
      *             if the number is zero or even
@@ -259,9 +242,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * It uses {@code AccessibleObject.setAccessible} to gain access to private fields. This means that it will
@@ -271,7 +252,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      *
      * <p>
      * If the TestTransients parameter is set to {@code true}, transient members will be tested, otherwise they
-     * are ignored, as they are likely derived fields, and not part of the value of the {@code Object}.
+     * are ignored, as they are likely derived fields, and not part of the value of the {@link Object}.
      * </p>
      *
      * <p>
@@ -293,7 +274,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param testTransients
      *            whether to include transient fields
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the Object is {@code null}
      * @throws IllegalArgumentException
      *             if the number is zero or even
@@ -306,9 +287,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * It uses {@code AccessibleObject.setAccessible} to gain access to private fields. This means that it will
@@ -318,7 +297,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      *
      * <p>
      * If the TestTransients parameter is set to {@code true}, transient members will be tested, otherwise they
-     * are ignored, as they are likely derived fields, and not part of the value of the {@code Object}.
+     * are ignored, as they are likely derived fields, and not part of the value of the {@link Object}.
      * </p>
      *
      * <p>
@@ -347,7 +326,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param excludeFields
      *            array of field names to exclude from use in calculation of hash code
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the Object is {@code null}
      * @throws IllegalArgumentException
      *             if the number is zero or even
@@ -357,7 +336,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      */
     public static <T> int reflectionHashCode(final int initialNonZeroOddNumber, final int multiplierNonZeroOddNumber, final T object,
             final boolean testTransients, final Class<? super T> reflectUpToClass, final String... excludeFields) {
-        Validate.notNull(object, "object");
+        Objects.requireNonNull(object, "object");
         final HashCodeBuilder builder = new HashCodeBuilder(initialNonZeroOddNumber, multiplierNonZeroOddNumber);
         Class<?> clazz = object.getClass();
         reflectionAppend(object, clazz, builder, testTransients, excludeFields);
@@ -369,9 +348,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * This constructor uses two hard coded choices for the constants needed to build a hash code.
@@ -383,9 +360,9 @@ public class HashCodeBuilder implements Builder<Integer> {
      * also not as efficient as testing explicitly.
      * </p>
      *
-     * <P>
+     * <p>
      * If the TestTransients parameter is set to {@code true}, transient members will be tested, otherwise they
-     * are ignored, as they are likely derived fields, and not part of the value of the {@code Object}.
+     * are ignored, as they are likely derived fields, and not part of the value of the {@link Object}.
      * </p>
      *
      * <p>
@@ -398,7 +375,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param testTransients
      *            whether to include transient fields
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the object is {@code null}
      *
      * @see HashCodeExclude
@@ -409,9 +386,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * This constructor uses two hard coded choices for the constants needed to build a hash code.
@@ -425,7 +400,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      *
      * <p>
      * Transient members will be not be used, as they are likely derived fields, and not part of the value of the
-     * {@code Object}.
+     * {@link Object}.
      * </p>
      *
      * <p>
@@ -438,7 +413,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param excludeFields
      *            Collection of String field names to exclude from use in calculation of hash code
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the object is {@code null}
      *
      * @see HashCodeExclude
@@ -447,12 +422,8 @@ public class HashCodeBuilder implements Builder<Integer> {
         return reflectionHashCode(object, ReflectionToStringBuilder.toNoNullStringArray(excludeFields));
     }
 
-    // -------------------------------------------------------------------------
-
     /**
-     * <p>
      * Uses reflection to build a valid hash code from the fields of {@code object}.
-     * </p>
      *
      * <p>
      * This constructor uses two hard coded choices for the constants needed to build a hash code.
@@ -466,7 +437,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      *
      * <p>
      * Transient members will be not be used, as they are likely derived fields, and not part of the value of the
-     * {@code Object}.
+     * {@link Object}.
      * </p>
      *
      * <p>
@@ -479,7 +450,7 @@ public class HashCodeBuilder implements Builder<Integer> {
      * @param excludeFields
      *            array of field names to exclude from use in calculation of hash code
      * @return int hash code
-     * @throws IllegalArgumentException
+     * @throws NullPointerException
      *             if the object is {@code null}
      *
      * @see HashCodeExclude
@@ -490,9 +461,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Registers the given object. Used by the reflection methods to avoid infinite loops.
-     * </p>
      *
      * @param value
      *            The object to register.
@@ -507,9 +476,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Unregisters the given object.
-     * </p>
      *
      * <p>
      * Used by the reflection methods to avoid infinite loops.
@@ -539,9 +506,8 @@ public class HashCodeBuilder implements Builder<Integer> {
     private int iTotal;
 
     /**
-     * <p>
      * Uses two hard coded choices for the constants needed to build a {@code hashCode}.
-     * </p>
+     *
      */
     public HashCodeBuilder() {
         iConstant = 37;
@@ -549,10 +515,8 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Two randomly chosen, odd numbers must be passed in. Ideally these should be different for each class,
      * however this is not vital.
-     * </p>
      *
      * <p>
      * Prime numbers are preferred, especially for the multiplier.
@@ -573,9 +537,8 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code boolean}.
-     * </p>
+     *
      * <p>
      * This adds {@code 1} when true, and {@code 0} when false to the {@code hashCode}.
      * </p>
@@ -599,9 +562,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code boolean} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -618,12 +579,8 @@ public class HashCodeBuilder implements Builder<Integer> {
         return this;
     }
 
-    // -------------------------------------------------------------------------
-
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code byte}.
-     * </p>
      *
      * @param value
      *            the byte to add to the {@code hashCode}
@@ -634,12 +591,8 @@ public class HashCodeBuilder implements Builder<Integer> {
         return this;
     }
 
-    // -------------------------------------------------------------------------
-
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code byte} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -657,9 +610,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code char}.
-     * </p>
      *
      * @param value
      *            the char to add to the {@code hashCode}
@@ -671,9 +622,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code char} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -691,9 +640,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code double}.
-     * </p>
      *
      * @param value
      *            the double to add to the {@code hashCode}
@@ -704,9 +651,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code double} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -724,9 +669,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code float}.
-     * </p>
      *
      * @param value
      *            the float to add to the {@code hashCode}
@@ -738,9 +681,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code float} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -758,9 +699,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for an {@code int}.
-     * </p>
      *
      * @param value
      *            the int to add to the {@code hashCode}
@@ -772,9 +711,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for an {@code int} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -792,9 +729,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code long}.
-     * </p>
      *
      * @param value
      *            the long to add to the {@code hashCode}
@@ -805,14 +740,12 @@ public class HashCodeBuilder implements Builder<Integer> {
     //       some stage. There are backwards compat issues, so
     //       that will have to wait for the time being. cf LANG-342.
     public HashCodeBuilder append(final long value) {
-        iTotal = iTotal * iConstant + ((int) (value ^ (value >> 32)));
+        iTotal = iTotal * iConstant + (int) (value ^ value >> 32);
         return this;
     }
 
     /**
-     * <p>
      * Append a {@code hashCode} for a {@code long} array.
-     * </p>
      *
      * @param array
      *            the array to add to the {@code hashCode}
@@ -830,9 +763,7 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
-     * Append a {@code hashCode} for an {@code Object}.
-     * </p>
+     * Append a {@code hashCode} for an {@link Object}.
      *
      * @param object
      *            the Object to add to the {@code hashCode}
@@ -842,7 +773,7 @@ public class HashCodeBuilder implements Builder<Integer> {
         if (object == null) {
             iTotal = iTotal * iConstant;
 
-        } else if (object.getClass().isArray()) {
+        } else if (ObjectUtils.isArray(object)) {
             // factor out array case in order to keep method small enough
             // to be inlined
             appendArray(object);
@@ -853,16 +784,62 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
+     * Append a {@code hashCode} for an {@link Object} array.
+     *
+     * @param array
+     *            the array to add to the {@code hashCode}
+     * @return this
+     */
+    public HashCodeBuilder append(final Object[] array) {
+        if (array == null) {
+            iTotal = iTotal * iConstant;
+        } else {
+            for (final Object element : array) {
+                append(element);
+            }
+        }
+        return this;
+    }
+
+    /**
+     * Append a {@code hashCode} for a {@code short}.
+     *
+     * @param value
+     *            the short to add to the {@code hashCode}
+     * @return this
+     */
+    public HashCodeBuilder append(final short value) {
+        iTotal = iTotal * iConstant + value;
+        return this;
+    }
+
+    /**
+     * Append a {@code hashCode} for a {@code short} array.
+     *
+     * @param array
+     *            the array to add to the {@code hashCode}
+     * @return this
+     */
+    public HashCodeBuilder append(final short[] array) {
+        if (array == null) {
+            iTotal = iTotal * iConstant;
+        } else {
+            for (final short element : array) {
+                append(element);
+            }
+        }
+        return this;
+    }
+
+    /**
      * Append a {@code hashCode} for an array.
-     * </p>
      *
      * @param object
      *            the array to add to the {@code hashCode}
      */
     private void appendArray(final Object object) {
         // 'Switch' on type of array, to dispatch to the correct handler
-        // This handles multi dimensional arrays
+        // This handles multidimensional arrays
         if (object instanceof long[]) {
             append((long[]) object);
         } else if (object instanceof int[]) {
@@ -886,67 +863,11 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
-     * Append a {@code hashCode} for an {@code Object} array.
-     * </p>
-     *
-     * @param array
-     *            the array to add to the {@code hashCode}
-     * @return this
-     */
-    public HashCodeBuilder append(final Object[] array) {
-        if (array == null) {
-            iTotal = iTotal * iConstant;
-        } else {
-            for (final Object element : array) {
-                append(element);
-            }
-        }
-        return this;
-    }
-
-    /**
-     * <p>
-     * Append a {@code hashCode} for a {@code short}.
-     * </p>
-     *
-     * @param value
-     *            the short to add to the {@code hashCode}
-     * @return this
-     */
-    public HashCodeBuilder append(final short value) {
-        iTotal = iTotal * iConstant + value;
-        return this;
-    }
-
-    /**
-     * <p>
-     * Append a {@code hashCode} for a {@code short} array.
-     * </p>
-     *
-     * @param array
-     *            the array to add to the {@code hashCode}
-     * @return this
-     */
-    public HashCodeBuilder append(final short[] array) {
-        if (array == null) {
-            iTotal = iTotal * iConstant;
-        } else {
-            for (final short element : array) {
-                append(element);
-            }
-        }
-        return this;
-    }
-
-    /**
-     * <p>
      * Adds the result of super.hashCode() to this builder.
-     * </p>
      *
      * @param superHashCode
      *            the result of calling {@code super.hashCode()}
-     * @return this HashCodeBuilder, used to chain calls.
+     * @return this
      * @since 2.0
      */
     public HashCodeBuilder appendSuper(final int superHashCode) {
@@ -954,22 +875,10 @@ public class HashCodeBuilder implements Builder<Integer> {
         return this;
     }
 
-    /**
-     * <p>
-     * Returns the computed {@code hashCode}.
-     * </p>
-     *
-     * @return {@code hashCode} based on the fields appended
-     */
-    public int toHashCode() {
-        return iTotal;
-    }
-
     /**
      * Returns the computed {@code hashCode}.
      *
      * @return {@code hashCode} based on the fields appended
-     *
      * @since 3.0
      */
     @Override
@@ -978,10 +887,26 @@ public class HashCodeBuilder implements Builder<Integer> {
     }
 
     /**
-     * <p>
+     * Implements equals using the hash code.
+     *
+     * @since 3.13.0
+     */
+    @Override
+    public boolean equals(final Object obj) {
+        if (this == obj) {
+            return true;
+        }
+        if (!(obj instanceof HashCodeBuilder)) {
+            return false;
+        }
+        final HashCodeBuilder other = (HashCodeBuilder) obj;
+        return iTotal == other.iTotal;
+    }
+
+    /**
      * The computed {@code hashCode} from toHashCode() is returned due to the likelihood
      * of bugs in mis-calling toHashCode() and the unlikeliness of it mattering what the hashCode for
-     * HashCodeBuilder itself is.</p>
+     * HashCodeBuilder itself is.
      *
      * @return {@code hashCode} based on the fields appended
      * @since 2.5
@@ -991,4 +916,13 @@ public class HashCodeBuilder implements Builder<Integer> {
         return toHashCode();
     }
 
+    /**
+     * Returns the computed {@code hashCode}.
+     *
+     * @return {@code hashCode} based on the fields appended
+     */
+    public int toHashCode() {
+        return iTotal;
+    }
+
 }
