@@ -23,28 +23,29 @@ import java.lang.reflect.InvocationTargetException;
 import java.lang.reflect.Method;
 import java.lang.reflect.UndeclaredThrowableException;
 import java.util.ArrayList;
+import java.util.Collections;
 import java.util.List;
 import java.util.Objects;
 import java.util.StringTokenizer;
+import java.util.function.Consumer;
+import java.util.stream.Stream;
 
 import org.apache.commons.lang3.ArrayUtils;
 import org.apache.commons.lang3.ClassUtils;
 import org.apache.commons.lang3.StringUtils;
 
 /**
- * <p>Provides utilities for manipulating and examining
- * {@code Throwable} objects.</p>
+ * Provides utilities for manipulating and examining
+ * {@link Throwable} objects.
  *
  * @since 1.0
  */
 public class ExceptionUtils {
 
-    private static final int NOT_FOUND = -1;
-
     /**
-     * <p>The names of methods commonly used to access a wrapped exception.</p>
+     * The names of methods commonly used to access a wrapped exception.
      */
-    // TODO: Remove in Lang 4.0
+    // TODO: Remove in Lang 4
     private static final String[] CAUSE_METHOD_NAMES = {
         "getCause",
         "getNextException",
@@ -60,21 +61,117 @@ public class ExceptionUtils {
         "getThrowable",
     };
 
+    private static final int NOT_FOUND = -1;
+
     /**
-     * <p>Used when printing stack frames to denote the start of a
-     * wrapped exception.</p>
+     * Used when printing stack frames to denote the start of a
+     * wrapped exception.
      *
      * <p>Package private for accessibility by test suite.</p>
      */
     static final String WRAPPED_MARKER = " [wrapped] ";
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Introspects the {@code Throwable} to obtain the cause.</p>
+     * Use to throws a checked exception without adding the exception to the throws
+     * clause of the calling method. This method prevents throws clause
+     * pollution and reduces the clutter of "Caused by" exceptions in the
+     * stack trace.
+     * <p>
+     * The use of this technique may be controversial, but exceedingly useful to
+     * library developers.
+     * </p>
+     * <pre>
+     *  public int propagateExample { // note that there is no throws clause
+     *      try {
+     *          return invocation(); // throws IOException
+     *      } catch (Exception e) {
+     *          return ExceptionUtils.rethrowRuntimeException(e);  // propagates a checked exception
+     *      }
+     *  }
+     * </pre>
+     * <p>
+     * This is an alternative to the more conservative approach of wrapping the
+     * checked exception in a RuntimeException:
+     * </p>
+     * <pre>
+     *  public int wrapExample { // note that there is no throws clause
+     *      try {
+     *          return invocation(); // throws IOException
+     *      } catch (Error e) {
+     *          throw e;
+     *      } catch (RuntimeException e) {
+     *          throw e;  // wraps a checked exception
+     *      } catch (Exception e) {
+     *          throw new UndeclaredThrowableException(e);  // wraps a checked exception
+     *      }
+     *  }
+     * </pre>
+     * <p>
+     * One downside to using this approach is that the java compiler will not
+     * allow invoking code to specify a checked exception in a catch clause
+     * unless there is some code path within the try block that has invoked a
+     * method declared with that checked exception. If the invoking site wishes
+     * to catch the shaded checked exception, it must either invoke the shaded
+     * code through a method re-declaring the desired checked exception, or
+     * catch Exception and use the {@code instanceof} operator. Either of these
+     * techniques are required when interacting with non-java jvm code such as
+     * Jython, Scala, or Groovy, since these languages do not consider any
+     * exceptions as checked.
+     * </p>
+     *
+     * @param throwable
+     *            The throwable to rethrow.
+     * @param <T> The type of the returned value.
+     * @return Never actually returned, this generic type matches any type
+     *         which the calling site requires. "Returning" the results of this
+     *         method, as done in the propagateExample above, will satisfy the
+     *         java compiler requirement that all code paths return a value.
+     * @since 3.14.0
+     * @see #wrapAndThrow(Throwable)
+     */
+    public static <T extends RuntimeException> T asRuntimeException(final Throwable throwable) {
+        // claim that the typeErasure invocation throws a RuntimeException
+        return ExceptionUtils.<T, RuntimeException>eraseType(throwable);
+    }
+
+    /**
+     * Claims a Throwable is another Throwable type using type erasure. This
+     * hides a checked exception from the Java compiler, allowing a checked
+     * exception to be thrown without having the exception in the method's throw
+     * clause.
+     */
+    @SuppressWarnings("unchecked")
+    private static <R, T extends Throwable> R eraseType(final Throwable throwable) throws T {
+        throw (T) throwable;
+    }
+
+    /**
+     * Performs an action for each Throwable causes of the given Throwable.
+     * <p>
+     * A throwable without cause will return a stream containing one element - the input throwable. A throwable with one cause
+     * will return a stream containing two elements. - the input throwable and the cause throwable. A {@code null} throwable
+     * will return a stream of count zero.
+     * </p>
+     *
+     * <p>
+     * This method handles recursive cause structures that might otherwise cause infinite loops. The cause chain is
+     * processed until the end is reached, or until the next item in the chain is already in the result set.
+     * </p>
+     * @param throwable The Throwable to traverse.
+     * @param consumer a non-interfering action to perform on the elements.
+     * @since 3.13.0
+     */
+    public static void forEach(final Throwable throwable, final Consumer<Throwable> consumer) {
+        stream(throwable).forEach(consumer);
+    }
+
+    /**
+     * Introspects the {@link Throwable} to obtain the cause.
      *
      * <p>The method searches for methods with specific names that return a
-     * {@code Throwable} object. This will pick up most wrapping exceptions,
+     * {@link Throwable} object. This will pick up most wrapping exceptions,
      * including those from JDK 1.4.
+     * </p>
      *
      * <p>The default list searched for are:</p>
      * <ul>
@@ -91,10 +188,10 @@ public class ExceptionUtils {
      * <p>If none of the above is found, returns {@code null}.</p>
      *
      * @param throwable  the throwable to introspect for a cause, may be null
-     * @return the cause of the {@code Throwable},
+     * @return the cause of the {@link Throwable},
      *  {@code null} if none found or null throwable input
      * @since 1.0
-     * @deprecated This feature will be removed in Lang 4.0, use {@link Throwable#getCause} instead
+     * @deprecated This feature will be removed in Lang 4, use {@link Throwable#getCause} instead
      */
     @Deprecated
     public static Throwable getCause(final Throwable throwable) {
@@ -102,92 +199,81 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Introspects the {@code Throwable} to obtain the cause.</p>
+     * Introspects the {@link Throwable} to obtain the cause.
      *
      * <p>A {@code null} set of method names means use the default set.
      * A {@code null} in the set of method names will be ignored.</p>
      *
      * @param throwable  the throwable to introspect for a cause, may be null
      * @param methodNames  the method names, null treated as default set
-     * @return the cause of the {@code Throwable},
+     * @return the cause of the {@link Throwable},
      *  {@code null} if none found or null throwable input
      * @since 1.0
-     * @deprecated This feature will be removed in Lang 4.0, use {@link Throwable#getCause} instead
+     * @deprecated This feature will be removed in Lang 4, use {@link Throwable#getCause} instead
      */
     @Deprecated
     public static Throwable getCause(final Throwable throwable, String[] methodNames) {
         if (throwable == null) {
             return null;
         }
-
         if (methodNames == null) {
             final Throwable cause = throwable.getCause();
             if (cause != null) {
                 return cause;
             }
-
             methodNames = CAUSE_METHOD_NAMES;
         }
-
-        for (final String methodName : methodNames) {
-            if (methodName != null) {
-                final Throwable legacyCause = getCauseUsingMethodName(throwable, methodName);
-                if (legacyCause != null) {
-                    return legacyCause;
-                }
-            }
-        }
-
-        return null;
+        return Stream.of(methodNames).map(m -> getCauseUsingMethodName(throwable, m)).filter(Objects::nonNull).findFirst().orElse(null);
     }
 
     /**
-     * <p>Finds a {@code Throwable} by method name.</p>
+     * Gets a {@link Throwable} by method name.
      *
      * @param throwable  the exception to examine
      * @param methodName  the name of the method to find and invoke
      * @return the wrapped exception, or {@code null} if not found
      */
-    // TODO: Remove in Lang 4.0
+    // TODO: Remove in Lang 4
     private static Throwable getCauseUsingMethodName(final Throwable throwable, final String methodName) {
-        Method method = null;
-        try {
-            method = throwable.getClass().getMethod(methodName);
-        } catch (final NoSuchMethodException | SecurityException ignored) { // NOPMD
-            // exception ignored
-        }
-
-        if (method != null && Throwable.class.isAssignableFrom(method.getReturnType())) {
+        if (methodName != null) {
+            Method method = null;
             try {
-                return (Throwable) method.invoke(throwable);
-            } catch (final IllegalAccessException | IllegalArgumentException | InvocationTargetException ignored) { // NOPMD
+                method = throwable.getClass().getMethod(methodName);
+            } catch (final NoSuchMethodException | SecurityException ignored) {
                 // exception ignored
             }
+
+            if (method != null && Throwable.class.isAssignableFrom(method.getReturnType())) {
+                try {
+                    return (Throwable) method.invoke(throwable);
+                } catch (final IllegalAccessException | IllegalArgumentException | InvocationTargetException ignored) {
+                    // exception ignored
+                }
+            }
         }
         return null;
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Returns the default names used when searching for the cause of an exception.</p>
+     * Gets the default names used when searching for the cause of an exception.
      *
      * <p>This may be modified and used in the overloaded getCause(Throwable, String[]) method.</p>
      *
      * @return cloned array of the default method names
      * @since 3.0
-     * @deprecated This feature will be removed in Lang 4.0
+     * @deprecated This feature will be removed in Lang 4
      */
     @Deprecated
     public static String[] getDefaultCauseMethodNames() {
         return ArrayUtils.clone(CAUSE_METHOD_NAMES);
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * Gets a short message summarising the exception.
+     * Gets a short message summarizing the exception.
      * <p>
      * The message returned is of the form
      * {ClassNameWithoutPackage}: {ThrowableMessage}
+     * </p>
      *
      * @param th  the throwable to get a message for, null returns empty string
      * @return the message, non-null
@@ -198,12 +284,11 @@ public class ExceptionUtils {
             return StringUtils.EMPTY;
         }
         final String clsName = ClassUtils.getShortClassName(th, null);
-        final String msg = th.getMessage();
-        return clsName + ": " + StringUtils.defaultString(msg);
+        return clsName + ": " + StringUtils.defaultString(th.getMessage());
     }
 
     /**
-     * <p>Introspects the {@code Throwable} to obtain the root cause.</p>
+     * Introspects the {@link Throwable} to obtain the root cause.
      *
      * <p>This method walks through the exception chain to the last element,
      * "root" of the tree, using {@link Throwable#getCause()}, and
@@ -216,7 +301,7 @@ public class ExceptionUtils {
      * loop is returned.</p>
      *
      * @param throwable  the throwable to get the root cause for, may be null
-     * @return the root cause of the {@code Throwable},
+     * @return the root cause of the {@link Throwable},
      *  {@code null} if null throwable input
      */
     public static Throwable getRootCause(final Throwable throwable) {
@@ -224,27 +309,25 @@ public class ExceptionUtils {
         return list.isEmpty() ? null : list.get(list.size() - 1);
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * Gets a short message summarising the root cause exception.
+     * Gets a short message summarizing the root cause exception.
      * <p>
      * The message returned is of the form
      * {ClassNameWithoutPackage}: {ThrowableMessage}
+     * </p>
      *
-     * @param th  the throwable to get a message for, null returns empty string
+     * @param throwable  the throwable to get a message for, null returns empty string
      * @return the message, non-null
      * @since 2.2
      */
-    public static String getRootCauseMessage(final Throwable th) {
-        Throwable root = getRootCause(th);
-        root = root == null ? th : root;
-        return getMessage(root);
+    public static String getRootCauseMessage(final Throwable throwable) {
+        final Throwable root = getRootCause(throwable);
+        return getMessage(root == null ? throwable : root);
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Creates a compact stack trace for the root cause of the supplied
-     * {@code Throwable}.</p>
+     * Gets a compact stack trace for the root cause of the supplied
+     * {@link Throwable}.
      *
      * <p>The output of this method is consistent across JDK versions.
      * It consists of the root exception followed by each of its wrapping
@@ -256,8 +339,24 @@ public class ExceptionUtils {
      * @since 2.0
      */
     public static String[] getRootCauseStackTrace(final Throwable throwable) {
+        return getRootCauseStackTraceList(throwable).toArray(ArrayUtils.EMPTY_STRING_ARRAY);
+    }
+
+    /**
+     * Gets a compact stack trace for the root cause of the supplied {@link Throwable}.
+     *
+     * <p>
+     * The output of this method is consistent across JDK versions. It consists of the root exception followed by each of
+     * its wrapping exceptions separated by '[wrapped]'. Note that this is the opposite order to the JDK1.4 display.
+     * </p>
+     *
+     * @param throwable the throwable to examine, may be null
+     * @return a list of stack trace frames, never null
+     * @since 3.13.0
+     */
+    public static List<String> getRootCauseStackTraceList(final Throwable throwable) {
         if (throwable == null) {
-            return ArrayUtils.EMPTY_STRING_ARRAY;
+            return Collections.emptyList();
         }
         final Throwable[] throwables = getThrowables(throwable);
         final int count = throwables.length;
@@ -276,23 +375,23 @@ public class ExceptionUtils {
             }
             frames.addAll(trace);
         }
-        return frames.toArray(ArrayUtils.EMPTY_STRING_ARRAY);
+        return frames;
     }
 
     /**
-     * <p>Produces a {@code List} of stack frames - the message
+     * Gets a {@link List} of stack frames - the message
      * is not included. Only the trace of the specified exception is
-     * returned, any caused by trace is stripped.</p>
+     * returned, any caused by trace is stripped.
      *
      * <p>This works in most cases - it will only fail if the exception
      * message contains a line that starts with:
      * {@code &quot;&nbsp;&nbsp;&nbsp;at&quot;.}</p>
      *
-     * @param t is any throwable
+     * @param throwable is any throwable
      * @return List of stack frames
      */
-    static List<String> getStackFrameList(final Throwable t) {
-        final String stackTrace = getStackTrace(t);
+    static List<String> getStackFrameList(final Throwable throwable) {
+        final String stackTrace = getStackTrace(throwable);
         final String linebreak = System.lineSeparator();
         final StringTokenizer frames = new StringTokenizer(stackTrace, linebreak);
         final List<String> list = new ArrayList<>();
@@ -311,9 +410,8 @@ public class ExceptionUtils {
         return list;
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Returns an array where each element is a line from the argument.</p>
+     * Gets an array where each element is a line from the argument.
      *
      * <p>The end of line is determined by the value of {@link System#lineSeparator()}.</p>
      *
@@ -331,16 +429,16 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Captures the stack trace associated with the specified
-     * {@code Throwable} object, decomposing it into a list of
-     * stack frames.</p>
+     * Gets the stack trace associated with the specified
+     * {@link Throwable} object, decomposing it into a list of
+     * stack frames.
      *
      * <p>The result of this method vary by JDK version as this method
      * uses {@link Throwable#printStackTrace(java.io.PrintWriter)}.
      * On JDK1.3 and earlier, the cause exception will not be shown
      * unless the specified throwable alters printStackTrace.</p>
      *
-     * @param throwable  the {@code Throwable} to examine, may be null
+     * @param throwable  the {@link Throwable} to examine, may be null
      * @return an array of strings describing each stack frame, never null
      */
     public static String[] getStackFrames(final Throwable throwable) {
@@ -350,30 +448,30 @@ public class ExceptionUtils {
         return getStackFrames(getStackTrace(throwable));
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Gets the stack trace from a Throwable as a String.</p>
+     * Gets the stack trace from a Throwable as a String.
      *
      * <p>The result of this method vary by JDK version as this method
      * uses {@link Throwable#printStackTrace(java.io.PrintWriter)}.
      * On JDK1.3 and earlier, the cause exception will not be shown
      * unless the specified throwable alters printStackTrace.</p>
      *
-     * @param throwable  the {@code Throwable} to be examined
+     * @param throwable  the {@link Throwable} to be examined, may be null
      * @return the stack trace as generated by the exception's
-     *  {@code printStackTrace(PrintWriter)} method
+     * {@code printStackTrace(PrintWriter)} method, or an empty String if {@code null} input
      */
     public static String getStackTrace(final Throwable throwable) {
+        if (throwable == null) {
+            return StringUtils.EMPTY;
+        }
         final StringWriter sw = new StringWriter();
-        final PrintWriter pw = new PrintWriter(sw, true);
-        throwable.printStackTrace(pw);
-        return sw.getBuffer().toString();
+        throwable.printStackTrace(new PrintWriter(sw, true));
+        return sw.toString();
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Counts the number of {@code Throwable} objects in the
-     * exception chain.</p>
+     * Gets a count of the number of {@link Throwable} objects in the
+     * exception chain.
      *
      * <p>A throwable without cause will return {@code 1}.
      * A throwable with one cause will return {@code 2} and so on.
@@ -392,8 +490,8 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the list of {@code Throwable} objects in the
-     * exception chain.</p>
+     * Gets the list of {@link Throwable} objects in the
+     * exception chain.
      *
      * <p>A throwable without cause will return a list containing
      * one element - the input throwable.
@@ -420,8 +518,8 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the list of {@code Throwable} objects in the
-     * exception chain.</p>
+     * Gets the list of {@link Throwable} objects in the
+     * exception chain.
      *
      * <p>A throwable without cause will return an array containing
      * one element - the input throwable.
@@ -439,12 +537,11 @@ public class ExceptionUtils {
      * @return the array of throwables, never null
      */
     public static Throwable[] getThrowables(final Throwable throwable) {
-        final List<Throwable> list = getThrowableList(throwable);
-        return list.toArray(ArrayUtils.EMPTY_THROWABLE_ARRAY);
+        return getThrowableList(throwable).toArray(ArrayUtils.EMPTY_THROWABLE_ARRAY);
     }
 
     /**
-     * Does the throwable's causal chain have an immediate or wrapped exception
+     * Tests if the throwable's causal chain have an immediate or wrapped exception
      * of the given type?
      *
      * @param chain
@@ -465,7 +562,7 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Worker method for the {@code indexOfType} methods.</p>
+     * Worker method for the {@code indexOfType} methods.
      *
      * @param throwable  the throwable to inspect, may be null
      * @param type  the type to search for, subclasses match, null returns -1
@@ -503,10 +600,10 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the (zero-based) index of the first {@code Throwable}
+     * Returns the (zero-based) index of the first {@link Throwable}
      * that matches the specified class (exactly) in the exception chain.
      * Subclasses of the specified class do not match - see
-     * {@link #indexOfType(Throwable, Class)} for the opposite.</p>
+     * {@link #indexOfType(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code -1}.
      * A {@code null} type returns {@code -1}.
@@ -521,11 +618,11 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the (zero-based) index of the first {@code Throwable}
+     * Returns the (zero-based) index of the first {@link Throwable}
      * that matches the specified type in the exception chain from
      * a specified index.
      * Subclasses of the specified class do not match - see
-     * {@link #indexOfType(Throwable, Class, int)} for the opposite.</p>
+     * {@link #indexOfType(Throwable, Class, int)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code -1}.
      * A {@code null} type returns {@code -1}.
@@ -544,10 +641,10 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the (zero-based) index of the first {@code Throwable}
+     * Returns the (zero-based) index of the first {@link Throwable}
      * that matches the specified class or subclass in the exception chain.
      * Subclasses of the specified class do match - see
-     * {@link #indexOfThrowable(Throwable, Class)} for the opposite.</p>
+     * {@link #indexOfThrowable(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code -1}.
      * A {@code null} type returns {@code -1}.
@@ -563,11 +660,11 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the (zero-based) index of the first {@code Throwable}
+     * Returns the (zero-based) index of the first {@link Throwable}
      * that matches the specified type in the exception chain from
      * a specified index.
      * Subclasses of the specified class do match - see
-     * {@link #indexOfThrowable(Throwable, Class)} for the opposite.</p>
+     * {@link #indexOfThrowable(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code -1}.
      * A {@code null} type returns {@code -1}.
@@ -586,10 +683,33 @@ public class ExceptionUtils {
         return indexOf(throwable, type, fromIndex, true);
     }
 
-    //-----------------------------------------------------------------------
     /**
-     * <p>Prints a compact stack trace for the root cause of a throwable
-     * to {@code System.err}.</p>
+     * Checks if a throwable represents a checked exception
+     *
+     * @param throwable
+     *            The throwable to check.
+     * @return True if the given Throwable is a checked exception.
+     * @since 3.13.0
+     */
+    public static boolean isChecked(final Throwable throwable) {
+        return throwable != null && !(throwable instanceof Error) && !(throwable instanceof RuntimeException);
+    }
+
+    /**
+     * Checks if a throwable represents an unchecked exception
+     *
+     * @param throwable
+     *            The throwable to check.
+     * @return True if the given Throwable is an unchecked exception.
+     * @since 3.13.0
+     */
+    public static boolean isUnchecked(final Throwable throwable) {
+        return throwable != null && (throwable instanceof Error || throwable instanceof RuntimeException);
+    }
+
+    /**
+     * Prints a compact stack trace for the root cause of a throwable
+     * to {@code System.err}.
      *
      * <p>The compact stack trace starts with the root cause and prints
      * stack frames up to the place where it was caught and wrapped.
@@ -610,7 +730,7 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Prints a compact stack trace for the root cause of a throwable.</p>
+     * Prints a compact stack trace for the root cause of a throwable.
      *
      * <p>The compact stack trace starts with the root cause and prints
      * stack frames up to the place where it was caught and wrapped.
@@ -634,15 +754,12 @@ public class ExceptionUtils {
             return;
         }
         Objects.requireNonNull(printStream, "printStream");
-        final String[] trace = getRootCauseStackTrace(throwable);
-        for (final String element : trace) {
-            printStream.println(element);
-        }
+        getRootCauseStackTraceList(throwable).forEach(printStream::println);
         printStream.flush();
     }
 
     /**
-     * <p>Prints a compact stack trace for the root cause of a throwable.</p>
+     * Prints a compact stack trace for the root cause of a throwable.
      *
      * <p>The compact stack trace starts with the root cause and prints
      * stack frames up to the place where it was caught and wrapped.
@@ -666,25 +783,21 @@ public class ExceptionUtils {
             return;
         }
         Objects.requireNonNull(printWriter, "printWriter");
-        final String[] trace = getRootCauseStackTrace(throwable);
-        for (final String element : trace) {
-            printWriter.println(element);
-        }
+        getRootCauseStackTraceList(throwable).forEach(printWriter::println);
         printWriter.flush();
     }
 
     /**
-     * <p>Removes common frames from the cause trace given the two stack traces.</p>
+     * Removes common frames from the cause trace given the two stack traces.
      *
      * @param causeFrames  stack trace of a cause throwable
      * @param wrapperFrames  stack trace of a wrapper throwable
-     * @throws IllegalArgumentException if either argument is null
+     * @throws NullPointerException if either argument is null
      * @since 2.0
      */
     public static void removeCommonFrames(final List<String> causeFrames, final List<String> wrapperFrames) {
-        if (causeFrames == null || wrapperFrames == null) {
-            throw new IllegalArgumentException("The List must not be null");
-        }
+        Objects.requireNonNull(causeFrames, "causeFrames");
+        Objects.requireNonNull(wrapperFrames, "wrapperFrames");
         int causeFrameIndex = causeFrames.size() - 1;
         int wrapperFrameIndex = wrapperFrames.size() - 1;
         while (causeFrameIndex >= 0 && wrapperFrameIndex >= 0) {
@@ -701,14 +814,15 @@ public class ExceptionUtils {
     }
 
     /**
-     * Throw a checked exception without adding the exception to the throws
+     * Use to throw a checked exception without adding the exception to the throws
      * clause of the calling method. This method prevents throws clause
      * pollution and reduces the clutter of "Caused by" exceptions in the
-     * stacktrace.
+     * stack trace.
      * <p>
      * The use of this technique may be controversial, but exceedingly useful to
      * library developers.
-     * <code>
+     * </p>
+     * <pre>
      *  public int propagateExample { // note that there is no throws clause
      *      try {
      *          return invocation(); // throws IOException
@@ -716,11 +830,12 @@ public class ExceptionUtils {
      *          return ExceptionUtils.rethrow(e);  // propagates a checked exception
      *      }
      *  }
-     * </code>
+     * </pre>
      * <p>
      * This is an alternative to the more conservative approach of wrapping the
      * checked exception in a RuntimeException:
-     * <code>
+     * </p>
+     * <pre>
      *  public int wrapExample { // note that there is no throws clause
      *      try {
      *          return invocation(); // throws IOException
@@ -732,7 +847,7 @@ public class ExceptionUtils {
      *          throw new UndeclaredThrowableException(e);  // wraps a checked exception
      *      }
      *  }
-     * </code>
+     * </pre>
      * <p>
      * One downside to using this approach is that the java compiler will not
      * allow invoking code to specify a checked exception in a catch clause
@@ -740,28 +855,53 @@ public class ExceptionUtils {
      * method declared with that checked exception. If the invoking site wishes
      * to catch the shaded checked exception, it must either invoke the shaded
      * code through a method re-declaring the desired checked exception, or
-     * catch Exception and use the instanceof operator. Either of these
+     * catch Exception and use the {@code instanceof} operator. Either of these
      * techniques are required when interacting with non-java jvm code such as
      * Jython, Scala, or Groovy, since these languages do not consider any
      * exceptions as checked.
+     * </p>
      *
      * @param throwable
      *            The throwable to rethrow.
-     * @param <R> The type of the returned value.
+     * @param <T> The type of the returned value.
      * @return Never actually returned, this generic type matches any type
      *         which the calling site requires. "Returning" the results of this
      *         method, as done in the propagateExample above, will satisfy the
      *         java compiler requirement that all code paths return a value.
      * @since 3.5
      * @see #wrapAndThrow(Throwable)
+     * @deprecated Use {@link #asRuntimeException(Throwable)}.
      */
-    public static <R> R rethrow(final Throwable throwable) {
+    @Deprecated
+    public static <T> T rethrow(final Throwable throwable) {
         // claim that the typeErasure invocation throws a RuntimeException
-        return ExceptionUtils.<R, RuntimeException>typeErasure(throwable);
+        return ExceptionUtils.<T, RuntimeException>eraseType(throwable);
     }
 
     /**
-     * <p>Worker method for the {@code throwableOfType} methods.</p>
+     * Streams causes of a Throwable.
+     * <p>
+     * A throwable without cause will return a stream containing one element - the input throwable. A throwable with one cause
+     * will return a stream containing two elements. - the input throwable and the cause throwable. A {@code null} throwable
+     * will return a stream of count zero.
+     * </p>
+     *
+     * <p>
+     * This method handles recursive cause structures that might otherwise cause infinite loops. The cause chain is
+     * processed until the end is reached, or until the next item in the chain is already in the result set.
+     * </p>
+     *
+     * @param throwable The Throwable to traverse
+     * @return A new Stream of Throwable causes.
+     * @since 3.13.0
+     */
+    public static Stream<Throwable> stream(final Throwable throwable) {
+        // No point building a custom Iterable as it would keep track of visited elements to avoid infinite loops
+        return getThrowableList(throwable).stream();
+    }
+
+    /**
+     * Worker method for the {@code throwableOfType} methods.
      *
      * @param <T> the type of Throwable you are searching.
      * @param throwable  the throwable to inspect, may be null
@@ -800,10 +940,10 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the first {@code Throwable}
+     * Returns the first {@link Throwable}
      * that matches the specified class (exactly) in the exception chain.
      * Subclasses of the specified class do not match - see
-     * {@link #throwableOfType(Throwable, Class)} for the opposite.</p>
+     * {@link #throwableOfType(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code null}.
      * A {@code null} type returns {@code null}.
@@ -820,11 +960,11 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the first {@code Throwable}
+     * Returns the first {@link Throwable}
      * that matches the specified type in the exception chain from
      * a specified index.
      * Subclasses of the specified class do not match - see
-     * {@link #throwableOfType(Throwable, Class, int)} for the opposite.</p>
+     * {@link #throwableOfType(Throwable, Class, int)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code null}.
      * A {@code null} type returns {@code null}.
@@ -845,10 +985,10 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the throwable of the first {@code Throwable}
+     * Returns the throwable of the first {@link Throwable}
      * that matches the specified class or subclass in the exception chain.
      * Subclasses of the specified class do match - see
-     * {@link #throwableOfThrowable(Throwable, Class)} for the opposite..</p>
+     * {@link #throwableOfThrowable(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code null}.
      * A {@code null} type returns {@code null}.
@@ -865,11 +1005,11 @@ public class ExceptionUtils {
     }
 
     /**
-     * <p>Returns the first {@code Throwable}
+     * Returns the first {@link Throwable}
      * that matches the specified type in the exception chain from
      * a specified index.
      * Subclasses of the specified class do match - see
-     * {@link #throwableOfThrowable(Throwable, Class)} for the opposite.</p>
+     * {@link #throwableOfThrowable(Throwable, Class)} for the opposite.
      *
      * <p>A {@code null} throwable returns {@code null}.
      * A {@code null} type returns {@code null}.
@@ -890,18 +1030,42 @@ public class ExceptionUtils {
     }
 
     /**
-     * Claim a Throwable is another Exception type using type erasure. This
-     * hides a checked exception from the java compiler, allowing a checked
-     * exception to be thrown without having the exception in the method's throw
-     * clause.
+     * Tests whether the specified {@link Throwable} is unchecked and throws it if so.
+     *
+     * @param <T> The Throwable type.
+     * @param throwable the throwable to test and throw or return.
+     * @return the given throwable.
+     * @since 3.13.0
+     * @deprecated Use {@link #throwUnchecked(Throwable)}.
      */
-    @SuppressWarnings("unchecked")
-    private static <R, T extends Throwable> R typeErasure(final Throwable throwable) throws T {
-        throw (T) throwable;
+    @Deprecated
+    public static <T> T throwUnchecked(final T throwable) {
+        if (throwable instanceof RuntimeException) {
+            throw (RuntimeException) throwable;
+        }
+        if (throwable instanceof Error) {
+            throw (Error) throwable;
+        }
+        return throwable;
     }
 
     /**
-     * Throw a checked exception without adding the exception to the throws
+     * Tests whether the specified {@link Throwable} is unchecked and throws it if so.
+     *
+     * @param <T> The Throwable type.
+     * @param throwable the throwable to test and throw or return.
+     * @return the given throwable.
+     * @since 3.14.0
+     */
+    public static <T extends Throwable> T throwUnchecked(final T throwable) {
+        if (isUnchecked(throwable)) {
+            throw asRuntimeException(throwable);
+        }
+        return throwable;
+    }
+
+    /**
+     * Throws a checked exception without adding the exception to the throws
      * clause of the calling method. For checked exceptions, this method throws
      * an UndeclaredThrowableException wrapping the checked exception. For
      * Errors and RuntimeExceptions, the original exception is rethrown.
@@ -909,6 +1073,7 @@ public class ExceptionUtils {
      * The downside to using this approach is that invoking code which needs to
      * handle specific checked exceptions must sniff up the exception chain to
      * determine if the caught exception was caused by the checked exception.
+     * </p>
      *
      * @param throwable
      *            The throwable to rethrow.
@@ -918,25 +1083,20 @@ public class ExceptionUtils {
      *         method will satisfy the java compiler requirement that all code
      *         paths return a value.
      * @since 3.5
-     * @see #rethrow(Throwable)
+     * @see #asRuntimeException(Throwable)
      * @see #hasCause(Throwable, Class)
      */
     public static <R> R wrapAndThrow(final Throwable throwable) {
-        if (throwable instanceof RuntimeException) {
-            throw (RuntimeException) throwable;
-        }
-        if (throwable instanceof Error) {
-            throw (Error) throwable;
-        }
-        throw new UndeclaredThrowableException(throwable);
+        throw new UndeclaredThrowableException(throwUnchecked(throwable));
     }
 
     /**
-     * <p>
-     * Public constructor allows an instance of {@code ExceptionUtils} to be created, although that is not
+     * Public constructor allows an instance of {@link ExceptionUtils} to be created, although that is not
      * normally necessary.
-     * </p>
+     *
+     * @deprecated Will be private in 3.0.
      */
+    @Deprecated
     public ExceptionUtils() {
     }
 }
