@@ -23,54 +23,53 @@ import java.util.concurrent.TimeUnit;
 import org.apache.commons.lang3.StringUtils;
 
 /**
- * <p>
- * {@code StopWatch} provides a convenient API for timings.
- * </p>
+ * {@link StopWatch} provides a convenient API for timings.
  *
  * <p>
  * To start the watch, call {@link #start()} or {@link StopWatch#createStarted()}. At this point you can:
  * </p>
  * <ul>
- * <li>{@link #split()} the watch to get the time whilst the watch continues in the background. {@link #unsplit()} will
- * remove the effect of the split. At this point, these three options are available again.</li>
- * <li>{@link #suspend()} the watch to pause it. {@link #resume()} allows the watch to continue. Any time between the
- * suspend and resume will not be counted in the total. At this point, these three options are available again.</li>
+ * <li>{@link #split()} the watch to get the time whilst the watch continues in the background. {@link #unsplit()} will remove the effect of the split. At this
+ * point, these three options are available again.</li>
+ * <li>{@link #suspend()} the watch to pause it. {@link #resume()} allows the watch to continue. Any time between the suspend and resume will not be counted in
+ * the total. At this point, these three options are available again.</li>
  * <li>{@link #stop()} the watch to complete the timing session.</li>
  * </ul>
  *
  * <p>
- * It is intended that the output methods {@link #toString()} and {@link #getTime()} should only be called after stop,
- * split or suspend, however a suitable result will be returned at other points.
+ * It is intended that the output methods {@link #toString()} and {@link #getTime()} should only be called after stop, split or suspend, however a suitable
+ * result will be returned at other points.
  * </p>
  *
  * <p>
- * NOTE: As from v2.1, the methods protect against inappropriate calls. Thus you cannot now call stop before start,
- * resume before suspend or unsplit before split.
+ * NOTE: As from v2.1, the methods protect against inappropriate calls. Thus you cannot now call stop before start, resume before suspend or unsplit before
+ * split.
  * </p>
  *
+ * <ol>
+ * <li>{@link #split()}, {@link #suspend()}, or {@link #stop()} cannot be invoked twice</li>
+ * <li>{@link #unsplit()} may only be called if the watch has been {@link #split()}</li>
+ * <li>{@link #resume()} may only be called if the watch has been {@link #suspend()}</li>
+ * <li>{@link #start()} cannot be called twice without calling {@link #reset()}</li>
+ * </ol>
+ *
  * <p>
- * 1. split(), suspend(), or stop() cannot be invoked twice<br>
- * 2. unsplit() may only be called if the watch has been split()<br>
- * 3. resume() may only be called if the watch has been suspend()<br>
- * 4. start() cannot be called twice without calling reset()
+ * This class is not thread-safe
  * </p>
  *
- * <p>This class is not thread-safe</p>
- *
  * @since 2.0
  */
 public class StopWatch {
 
     /**
-     * Enumeration type which indicates the split status of stopwatch.
+     * Enumeration type which indicates the split status of a StopWatch.
      */
     private enum SplitState {
-        SPLIT,
-        UNSPLIT
+        SPLIT, UNSPLIT
     }
 
     /**
-     * Enumeration type which indicates the status of stopwatch.
+     * Enumeration type which indicates the status of a StopWatch.
      */
     private enum State {
 
@@ -79,52 +78,63 @@ public class StopWatch {
             boolean isStarted() {
                 return true;
             }
+
             @Override
             boolean isStopped() {
                 return false;
             }
+
             @Override
             boolean isSuspended() {
                 return false;
             }
         },
+
         STOPPED {
             @Override
             boolean isStarted() {
                 return false;
             }
+
             @Override
             boolean isStopped() {
                 return true;
             }
+
             @Override
             boolean isSuspended() {
                 return false;
             }
         },
+
         SUSPENDED {
             @Override
             boolean isStarted() {
                 return true;
             }
+
             @Override
             boolean isStopped() {
                 return false;
             }
+
             @Override
             boolean isSuspended() {
                 return true;
             }
         },
+
         UNSTARTED {
             @Override
             boolean isStarted() {
                 return false;
             }
+
             @Override
             boolean isStopped() {
                 return true;
             }
+
             @Override
             boolean isSuspended() {
                 return false;
@@ -132,31 +142,23 @@ public class StopWatch {
         };
 
         /**
-         * <p>
-         * Returns whether the StopWatch is started. A suspended StopWatch is also started watch.
-         * </p>
+         * Tests whether the StopWatch is started. A suspended StopWatch is also started.
          *
          * @return boolean If the StopWatch is started.
          */
         abstract boolean isStarted();
 
         /**
-         * <p>
-         * Returns whether the StopWatch is stopped. The stopwatch which's not yet started and explicitly stopped stopwatch is
-         * considered as stopped.
-         * </p>
+         * Tests whether the StopWatch is stopped. A StopWatch which is not yet started and explicitly stopped is considered stopped.
          *
          * @return boolean If the StopWatch is stopped.
          */
         abstract boolean isStopped();
 
         /**
-         * <p>
-         * Returns whether the StopWatch is suspended.
-         * </p>
+         * Tests whether the StopWatch is suspended.
          *
-         * @return boolean
-         *             If the StopWatch is suspended.
+         * @return boolean If the StopWatch is suspended.
          */
         abstract boolean isSuspended();
     }
@@ -164,9 +166,9 @@ public class StopWatch {
     private static final long NANO_2_MILLIS = 1000000L;
 
     /**
-     * Creates a stopwatch for convenience.
+     * Creates a StopWatch.
      *
-     * @return StopWatch a stopwatch.
+     * @return StopWatch a StopWatch.
      *
      * @since 3.10
      */
@@ -175,9 +177,9 @@ public class StopWatch {
     }
 
     /**
-     * Creates a started stopwatch for convenience.
+     * Creates and starts a StopWatch.
      *
-     * @return StopWatch a stopwatch that's already been started.
+     * @return StopWatch a started StopWatch.
      *
      * @since 3.5
      */
@@ -200,40 +202,46 @@ public class StopWatch {
     private State runningState = State.UNSTARTED;
 
     /**
-     * Whether the stopwatch has a split time recorded.
+     * Whether the StopWatch has a split time recorded.
      */
     private SplitState splitState = SplitState.UNSPLIT;
 
     /**
-     * The start time.
+     * The start time in nanoseconds.
      */
-    private long startTime;
+    private long startTimeNanos;
 
     /**
-     * The start time in Millis - nanoTime is only for elapsed time so we
-     * need to also store the currentTimeMillis to maintain the old
-     * getStartTime API.
+     * The start time in milliseconds.
+     * <p>
+     * nanoTime is only for elapsed time so we need to also store the currentTimeMillis to maintain the old getStartTime API.
+     * </p>
      */
     private long startTimeMillis;
 
     /**
-     * The stop time.
+     * The end time in milliseconds.
+     * <p>
+     * nanoTime is only for elapsed time so we need to also store the currentTimeMillis to maintain the old getStartTime API.
+     * </p>
      */
-    private long stopTime;
+    private long stopTimeMillis;
+
+    /**
+     * The stop time in nanoseconds.
+     */
+    private long stopTimeNanos;
 
     /**
-     * <p>
      * Constructor.
-     * </p>
      */
     public StopWatch() {
         this(null);
     }
 
     /**
-     * <p>
-     * Constructor.
-     * </p>
+     * Constructs a new instance.
+     *
      * @param message A message for string presentation.
      * @since 3.10
      */
@@ -242,9 +250,9 @@ public class StopWatch {
     }
 
     /**
-     * Returns the time formatted by {@link DurationFormatUtils#formatDurationHMS}.
+     * Formats the split time with {@link DurationFormatUtils#formatDurationHMS}.
      *
-     * @return the time formatted by {@link DurationFormatUtils#formatDurationHMS}.
+     * @return the split time formatted by {@link DurationFormatUtils#formatDurationHMS}.
      * @since 3.10
      */
     public String formatSplitTime() {
@@ -252,9 +260,9 @@ public class StopWatch {
     }
 
     /**
-     * Returns the split time formatted by {@link DurationFormatUtils#formatDurationHMS}.
+     * Formats the time formatted with {@link DurationFormatUtils#formatDurationHMS}.
      *
-     * @return the split time formatted by {@link DurationFormatUtils#formatDurationHMS}.
+     * @return the time formatted by {@link DurationFormatUtils#formatDurationHMS}.
      * @since 3.10
      */
     public String formatTime() {
@@ -272,33 +280,31 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Gets the time on the stopwatch in nanoseconds.
-     * </p>
+     * Gets the <em>elapsed</em> time in nanoseconds.
      *
      * <p>
-     * This is either the time between the start and the moment this method is called, or the amount of time between
-     * start and stop.
+     * This is either the time between the start and the moment this method is called, or the amount of time between start and stop.
      * </p>
      *
-     * @return the time in nanoseconds
+     * @return the <em>elapsed</em> time in nanoseconds.
+     * @see System#nanoTime()
      * @since 3.0
      */
     public long getNanoTime() {
         if (this.runningState == State.STOPPED || this.runningState == State.SUSPENDED) {
-            return this.stopTime - this.startTime;
-        } else if (this.runningState == State.UNSTARTED) {
-            return 0;
-        } else if (this.runningState == State.RUNNING) {
-            return System.nanoTime() - this.startTime;
+            return this.stopTimeNanos - this.startTimeNanos;
         }
-        throw new RuntimeException("Illegal running state has occurred.");
+        if (this.runningState == State.UNSTARTED) {
+            return 0;
+        }
+        if (this.runningState == State.RUNNING) {
+            return System.nanoTime() - this.startTimeNanos;
+        }
+        throw new IllegalStateException("Illegal running state has occurred.");
     }
 
     /**
-     * <p>
-     * Gets the split time on the stopwatch in nanoseconds.
-     * </p>
+     * Gets the split time in nanoseconds.
      *
      * <p>
      * This is the time between start and latest split.
@@ -306,21 +312,18 @@ public class StopWatch {
      *
      * @return the split time in nanoseconds
      *
-     * @throws IllegalStateException
-     *             if the StopWatch has not yet been split.
+     * @throws IllegalStateException if the StopWatch has not yet been split.
      * @since 3.0
      */
     public long getSplitNanoTime() {
         if (this.splitState != SplitState.SPLIT) {
-            throw new IllegalStateException("Stopwatch must be split to get the split time. ");
+            throw new IllegalStateException("Stopwatch must be split to get the split time.");
         }
-        return this.stopTime - this.startTime;
+        return this.stopTimeNanos - this.startTimeNanos;
     }
 
     /**
-     * <p>
-     * Gets the split time on the stopwatch.
-     * </p>
+     * Gets the split time on the StopWatch.
      *
      * <p>
      * This is the time between start and latest split.
@@ -328,56 +331,63 @@ public class StopWatch {
      *
      * @return the split time in milliseconds
      *
-     * @throws IllegalStateException
-     *             if the StopWatch has not yet been split.
+     * @throws IllegalStateException if the StopWatch has not yet been split.
      * @since 2.1
      */
     public long getSplitTime() {
-        return getSplitNanoTime() / NANO_2_MILLIS;
+        return nanosToMillis(getSplitNanoTime());
     }
 
     /**
-     * Gets the time this stopwatch was started.
+     * Gets the time this StopWatch was started in milliseconds, between the current time and midnight, January 1, 1970 UTC.
      *
-     * @return the time this stopwatch was started
-     * @throws IllegalStateException
-     *             if this StopWatch has not been started
+     * @return the time this StopWatch was started in milliseconds, between the current time and midnight, January 1, 1970 UTC.
+     * @throws IllegalStateException if this StopWatch has not been started
      * @since 2.4
      */
     public long getStartTime() {
         if (this.runningState == State.UNSTARTED) {
             throw new IllegalStateException("Stopwatch has not been started");
         }
-        // System.nanoTime is for elapsed time
+        // stopTimeNanos stores System.nanoTime() for elapsed time
         return this.startTimeMillis;
     }
 
     /**
-     * <p>
-     * Gets the time on the stopwatch.
-     * </p>
+     * Gets the time this StopWatch was stopped in milliseconds, between the current time and midnight, January 1, 1970 UTC.
+     *
+     * @return the time this StopWatch was started in milliseconds, between the current time and midnight, January 1, 1970 UTC.
+     * @throws IllegalStateException if this StopWatch has not been started
+     * @since 3.12.0
+     */
+    public long getStopTime() {
+        if (this.runningState == State.UNSTARTED) {
+            throw new IllegalStateException("Stopwatch has not been started");
+        }
+        // stopTimeNanos stores System.nanoTime() for elapsed time
+        return this.stopTimeMillis;
+    }
+
+    /**
+     * Gets the time on the StopWatch.
      *
      * <p>
-     * This is either the time between the start and the moment this method is called, or the amount of time between
-     * start and stop.
+     * This is either the time between the start and the moment this method is called, or the amount of time between start and stop.
      * </p>
      *
      * @return the time in milliseconds
      */
     public long getTime() {
-        return getNanoTime() / NANO_2_MILLIS;
+        return nanosToMillis(getNanoTime());
     }
 
     /**
-     * <p>
-     * Gets the time on the stopwatch in the specified TimeUnit.
-     * </p>
+     * Gets the time in the specified TimeUnit.
      *
      * <p>
-     * This is either the time between the start and the moment this method is called, or the amount of time between
-     * start and stop. The resulting time will be expressed in the desired TimeUnit with any remainder rounded down.
-     * For example, if the specified unit is {@code TimeUnit.HOURS} and the stopwatch time is 59 minutes, then the
-     * result returned will be {@code 0}.
+     * This is either the time between the start and the moment this method is called, or the amount of time between start and stop. The resulting time will be
+     * expressed in the desired TimeUnit with any remainder rounded down. For example, if the specified unit is {@code TimeUnit.HOURS} and the StopWatch time is
+     * 59 minutes, then the result returned will be {@code 0}.
      * </p>
      *
      * @param timeUnit the unit of time, not null
@@ -389,9 +399,7 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Returns whether the StopWatch is started. A suspended StopWatch is also started watch.
-     * </p>
+     * Tests whether the StopWatch is started. A suspended StopWatch is also started watch.
      *
      * @return boolean If the StopWatch is started.
      * @since 3.2
@@ -401,10 +409,7 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Returns whether StopWatch is stopped. The stopwatch which's not yet started and explicitly stopped stopwatch is considered
-     * as stopped.
-     * </p>
+     * Tests whether StopWatch is stopped. The StopWatch which's not yet started and explicitly stopped StopWatch is considered as stopped.
      *
      * @return boolean If the StopWatch is stopped.
      * @since 3.2
@@ -414,12 +419,9 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Returns whether the StopWatch is suspended.
-     * </p>
+     * Tests whether the StopWatch is suspended.
      *
-     * @return boolean
-     *             If the StopWatch is suspended.
+     * @return boolean If the StopWatch is suspended.
      * @since 3.2
      */
     public boolean isSuspended() {
@@ -427,9 +429,17 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Resets the stopwatch. Stops it if need be.
-     * </p>
+     * Converts nanoseconds to milliseconds.
+     *
+     * @param nanos nanoseconds to convert.
+     * @return milliseconds conversion result.
+     */
+    private long nanosToMillis(long nanos) {
+        return nanos / NANO_2_MILLIS;
+    }
+
+    /**
+     * Resets the StopWatch. Stops it if need be.
      *
      * <p>
      * This method clears the internal values to allow the object to be reused.
@@ -439,59 +449,50 @@ public class StopWatch {
         this.runningState = State.UNSTARTED;
         this.splitState = SplitState.UNSPLIT;
     }
+
     /**
-     * <p>
-     * Resumes the stopwatch after a suspend.
-     * </p>
+     * Resumes the StopWatch after a suspend.
      *
      * <p>
-     * This method resumes the watch after it was suspended. The watch will not include time between the suspend and
-     * resume calls in the total time.
+     * This method resumes the watch after it was suspended. The watch will not include time between the suspend and resume calls in the total time.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch has not been suspended.
+     * @throws IllegalStateException if the StopWatch has not been suspended.
      */
     public void resume() {
         if (this.runningState != State.SUSPENDED) {
             throw new IllegalStateException("Stopwatch must be suspended to resume. ");
         }
-        this.startTime += System.nanoTime() - this.stopTime;
+        this.startTimeNanos += System.nanoTime() - this.stopTimeNanos;
         this.runningState = State.RUNNING;
     }
 
     /**
-     * <p>
      * Splits the time.
-     * </p>
      *
      * <p>
-     * This method sets the stop time of the watch to allow a time to be extracted. The start time is unaffected,
-     * enabling {@link #unsplit()} to continue the timing from the original start point.
+     * This method sets the stop time of the watch to allow a time to be extracted. The start time is unaffected, enabling {@link #unsplit()} to continue the
+     * timing from the original start point.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch is not running.
+     * @throws IllegalStateException if the StopWatch is not running.
      */
     public void split() {
         if (this.runningState != State.RUNNING) {
             throw new IllegalStateException("Stopwatch is not running. ");
         }
-        this.stopTime = System.nanoTime();
+        this.stopTimeNanos = System.nanoTime();
         this.splitState = SplitState.SPLIT;
     }
 
     /**
-     * <p>
-     * Starts the stopwatch.
-     * </p>
+     * Starts the StopWatch.
      *
      * <p>
      * This method starts a new timing session, clearing any previous values.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch is already running.
+     * @throws IllegalStateException if the StopWatch is already running.
      */
     public void start() {
         if (this.runningState == State.STOPPED) {
@@ -500,58 +501,51 @@ public class StopWatch {
         if (this.runningState != State.UNSTARTED) {
             throw new IllegalStateException("Stopwatch already started. ");
         }
-        this.startTime = System.nanoTime();
+        this.startTimeNanos = System.nanoTime();
         this.startTimeMillis = System.currentTimeMillis();
         this.runningState = State.RUNNING;
     }
 
     /**
-     * <p>
-     * Stops the stopwatch.
-     * </p>
+     * Stops the StopWatch.
      *
      * <p>
      * This method ends a new timing session, allowing the time to be retrieved.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch is not running.
+     * @throws IllegalStateException if the StopWatch is not running.
      */
     public void stop() {
         if (this.runningState != State.RUNNING && this.runningState != State.SUSPENDED) {
             throw new IllegalStateException("Stopwatch is not running. ");
         }
         if (this.runningState == State.RUNNING) {
-            this.stopTime = System.nanoTime();
+            this.stopTimeNanos = System.nanoTime();
+            this.stopTimeMillis = System.currentTimeMillis();
         }
         this.runningState = State.STOPPED;
     }
 
     /**
-     * <p>
-     * Suspends the stopwatch for later resumption.
-     * </p>
+     * Suspends the StopWatch for later resumption.
      *
      * <p>
-     * This method suspends the watch until it is resumed. The watch will not include time between the suspend and
-     * resume calls in the total time.
+     * This method suspends the watch until it is resumed. The watch will not include time between the suspend and resume calls in the total time.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch is not currently running.
+     * @throws IllegalStateException if the StopWatch is not currently running.
      */
     public void suspend() {
         if (this.runningState != State.RUNNING) {
             throw new IllegalStateException("Stopwatch must be running to suspend. ");
         }
-        this.stopTime = System.nanoTime();
+        this.stopTimeNanos = System.nanoTime();
+        this.stopTimeMillis = System.currentTimeMillis();
         this.runningState = State.SUSPENDED;
     }
 
     /**
-     * <p>
-     * Gets a summary of the split time that the stopwatch recorded as a string.
-     * </p>
+     * Gets a summary of the split time that the StopWatch recorded as a string.
      *
      * <p>
      * The format used is ISO 8601-like, [<i>message</i> ]<i>hours</i>:<i>minutes</i>:<i>seconds</i>.<i>milliseconds</i>.
@@ -568,9 +562,7 @@ public class StopWatch {
     }
 
     /**
-     * <p>
-     * Gets a summary of the time that the stopwatch recorded as a string.
-     * </p>
+     * Gets a summary of the time that the StopWatch recorded as a string.
      *
      * <p>
      * The format used is ISO 8601-like, [<i>message</i> ]<i>hours</i>:<i>minutes</i>:<i>seconds</i>.<i>milliseconds</i>.
@@ -587,17 +579,13 @@ public class StopWatch {
     }
 
     /**
-     * <p>
      * Removes a split.
-     * </p>
      *
      * <p>
-     * This method clears the stop time. The start time is unaffected, enabling timing from the original start point to
-     * continue.
+     * This method clears the stop time. The start time is unaffected, enabling timing from the original start point to continue.
      * </p>
      *
-     * @throws IllegalStateException
-     *             if the StopWatch has not been split.
+     * @throws IllegalStateException if the StopWatch has not been split.
      */
     public void unsplit() {
         if (this.splitState != SplitState.SPLIT) {
