@@ -39,46 +39,21 @@ import org.junit.jupiter.params.provider.MethodSource;
 /**
  * Tests CharSequenceUtils
  */
-public class CharSequenceUtilsTest {
+public class CharSequenceUtilsTest extends AbstractLangTest {
 
-    //-----------------------------------------------------------------------
-    @Test
-    public void testConstructor() {
-        assertNotNull(new CharSequenceUtils());
-        final Constructor<?>[] cons = CharSequenceUtils.class.getDeclaredConstructors();
-        assertEquals(1, cons.length);
-        assertTrue(Modifier.isPublic(cons[0].getModifiers()));
-        assertTrue(Modifier.isPublic(CharSequenceUtils.class.getModifiers()));
-        assertFalse(Modifier.isFinal(CharSequenceUtils.class.getModifiers()));
-    }
+    private abstract static class RunTest {
 
-    //-----------------------------------------------------------------------
-    @Test
-    public void testSubSequence() {
-        //
-        // null input
-        //
-        assertNull(CharSequenceUtils.subSequence(null, -1));
-        assertNull(CharSequenceUtils.subSequence(null, 0));
-        assertNull(CharSequenceUtils.subSequence(null, 1));
-        //
-        // non-null input
-        //
-        assertEquals(StringUtils.EMPTY, CharSequenceUtils.subSequence(StringUtils.EMPTY, 0));
-        assertEquals("012", CharSequenceUtils.subSequence("012", 0));
-        assertEquals("12", CharSequenceUtils.subSequence("012", 1));
-        assertEquals("2", CharSequenceUtils.subSequence("012", 2));
-        assertEquals(StringUtils.EMPTY, CharSequenceUtils.subSequence("012", 3));
-    }
+        abstract boolean invoke();
 
-    @Test
-    public void testSubSequenceNegativeStart() {
-        assertThrows(IndexOutOfBoundsException.class, () -> CharSequenceUtils.subSequence(StringUtils.EMPTY, -1));
-    }
+        void run(final TestData data, final String id) {
+            if (data.throwable != null) {
+                assertThrows(data.throwable, this::invoke, id + " Expected " + data.throwable);
+            } else {
+                final boolean stringCheck = invoke();
+                assertEquals(data.expected, stringCheck, id + " Failed test " + data);
+            }
+        }
 
-    @Test
-    public void testSubSequenceTooLong() {
-        assertThrows(IndexOutOfBoundsException.class, () -> CharSequenceUtils.subSequence(StringUtils.EMPTY, 1));
     }
 
     static class TestData{
@@ -128,6 +103,44 @@ public class CharSequenceUtilsTest {
         }
     }
 
+    static class WrapperString implements CharSequence {
+        private final CharSequence inner;
+
+        WrapperString(final CharSequence inner) {
+            this.inner = inner;
+        }
+
+        @Override
+        public char charAt(final int index) {
+            return inner.charAt(index);
+        }
+
+        @Override
+        public IntStream chars() {
+            return inner.chars();
+        }
+
+        @Override
+        public IntStream codePoints() {
+            return inner.codePoints();
+        }
+
+        @Override
+        public int length() {
+            return inner.length();
+        }
+
+        @Override
+        public CharSequence subSequence(final int start, final int end) {
+            return inner.subSequence(start, end);
+        }
+
+        @Override
+        public String toString() {
+            return inner.toString();
+        }
+    }
+
     private static final TestData[] TEST_DATA = {
             //          Source  IgnoreCase Offset Other  Offset Length Result
             new TestData("",    true,      -1,    "",    -1,    -1,    false),
@@ -145,19 +158,94 @@ public class CharSequenceUtilsTest {
             new TestData("Abcd", false,     1,     "abcD", 1,     2,     true),
     };
 
-    private abstract static class RunTest {
+    static Stream<Arguments> lastIndexWithStandardCharSequence() {
+        return Stream.of(
+            arguments("abc", "b", 2, 1),
+            arguments(new StringBuilder("abc"), "b", 2, 1),
+            arguments(new StringBuffer("abc"), "b", 2, 1),
+            arguments("abc", new StringBuilder("b"), 2, 1),
+            arguments(new StringBuilder("abc"), new StringBuilder("b"), 2, 1),
+            arguments(new StringBuffer("abc"), new StringBuffer("b"), 2, 1),
+            arguments(new StringBuilder("abc"), new StringBuffer("b"), 2, 1)
+        );
+    }
 
-        abstract boolean invoke();
+    @Test
+    public void testConstructor() {
+        assertNotNull(new CharSequenceUtils());
+        final Constructor<?>[] cons = CharSequenceUtils.class.getDeclaredConstructors();
+        assertEquals(1, cons.length);
+        assertTrue(Modifier.isPublic(cons[0].getModifiers()));
+        assertTrue(Modifier.isPublic(CharSequenceUtils.class.getModifiers()));
+        assertFalse(Modifier.isFinal(CharSequenceUtils.class.getModifiers()));
+    }
 
-        void run(final TestData data, final String id) {
-            if (data.throwable != null) {
-                assertThrows(data.throwable, this::invoke, id + " Expected " + data.throwable);
-            } else {
-                final boolean stringCheck = invoke();
-                assertEquals(data.expected, stringCheck, id + " Failed test " + data);
-            }
+    @ParameterizedTest
+    @MethodSource("lastIndexWithStandardCharSequence")
+    public void testLastIndexOfWithDifferentCharSequences(final CharSequence cs, final CharSequence search, final int start,
+                                                          final int expected) {
+        assertEquals(expected, CharSequenceUtils.lastIndexOf(cs, search, start));
+    }
+
+    @Test
+    public void testNewLastIndexOf() {
+        testNewLastIndexOfSingle("808087847-1321060740-635567660180086727-925755305", "-1321060740-635567660", 21);
+        testNewLastIndexOfSingle("", "");
+        testNewLastIndexOfSingle("1", "");
+        testNewLastIndexOfSingle("", "1");
+        testNewLastIndexOfSingle("1", "1");
+        testNewLastIndexOfSingle("11", "1");
+        testNewLastIndexOfSingle("1", "11");
+
+        testNewLastIndexOfSingle("apache", "a");
+        testNewLastIndexOfSingle("apache", "p");
+        testNewLastIndexOfSingle("apache", "e");
+        testNewLastIndexOfSingle("apache", "x");
+        testNewLastIndexOfSingle("oraoraoraora", "r");
+        testNewLastIndexOfSingle("mudamudamudamuda", "d");
+        // There is a route through checkLaterThan1#checkLaterThan1
+        // which only gets touched if there is a two letter (or more) partial match
+        // (in this case "st") earlier in the searched string.
+        testNewLastIndexOfSingle("junk-ststarting", "starting");
+
+        final Random random = new Random();
+        final StringBuilder seg = new StringBuilder();
+        while (seg.length() <= CharSequenceUtils.TO_STRING_LIMIT) {
+            seg.append(random.nextInt());
         }
+        StringBuilder original = new StringBuilder(seg);
+        testNewLastIndexOfSingle(original, seg);
+        for (int i = 0; i < 100; i++) {
+            if (random.nextDouble() < 0.5) {
+                original.append(random.nextInt() % 10);
+            } else {
+                original = new StringBuilder().append(String.valueOf(random.nextInt() % 100)).append(original);
+            }
+            testNewLastIndexOfSingle(original, seg);
+        }
+    }
 
+
+    private void testNewLastIndexOfSingle(final CharSequence a, final CharSequence b) {
+        final int maxa = Math.max(a.length(), b.length());
+        for (int i = -maxa - 10; i <= maxa + 10; i++) {
+            testNewLastIndexOfSingle(a, b, i);
+        }
+        testNewLastIndexOfSingle(a, b, Integer.MIN_VALUE);
+        testNewLastIndexOfSingle(a, b, Integer.MAX_VALUE);
+    }
+
+    private void testNewLastIndexOfSingle(final CharSequence a, final CharSequence b, final int start) {
+        testNewLastIndexOfSingleSingle(a, b, start);
+        testNewLastIndexOfSingleSingle(b, a, start);
+    }
+
+    private void testNewLastIndexOfSingleSingle(final CharSequence a, final CharSequence b, final int start) {
+        assertEquals(
+                a.toString().lastIndexOf(b.toString(), start),
+                CharSequenceUtils.lastIndexOf(new WrapperString(a.toString()), new WrapperString(b.toString()), start),
+                "testNewLastIndexOf fails! original : " + a + " seg : " + b + " start : " + start
+        );
     }
 
     @Test
@@ -184,6 +272,33 @@ public class CharSequenceUtilsTest {
         }
     }
 
+    @Test
+    public void testSubSequence() {
+        //
+        // null input
+        //
+        assertNull(CharSequenceUtils.subSequence(null, -1));
+        assertNull(CharSequenceUtils.subSequence(null, 0));
+        assertNull(CharSequenceUtils.subSequence(null, 1));
+        //
+        // non-null input
+        //
+        assertEquals(StringUtils.EMPTY, CharSequenceUtils.subSequence(StringUtils.EMPTY, 0));
+        assertEquals("012", CharSequenceUtils.subSequence("012", 0));
+        assertEquals("12", CharSequenceUtils.subSequence("012", 1));
+        assertEquals("2", CharSequenceUtils.subSequence("012", 2));
+        assertEquals(StringUtils.EMPTY, CharSequenceUtils.subSequence("012", 3));
+    }
+
+    @Test
+    public void testSubSequenceNegativeStart() {
+        assertThrows(IndexOutOfBoundsException.class, () -> CharSequenceUtils.subSequence(StringUtils.EMPTY, -1));
+    }
+
+    @Test
+    public void testSubSequenceTooLong() {
+        assertThrows(IndexOutOfBoundsException.class, () -> CharSequenceUtils.subSequence(StringUtils.EMPTY, 1));
+    }
 
     @Test
     public void testToCharArray() {
@@ -193,117 +308,4 @@ public class CharSequenceUtilsTest {
         assertArrayEquals(expected, CharSequenceUtils.toCharArray(builder.toString()));
         assertArrayEquals(ArrayUtils.EMPTY_CHAR_ARRAY, CharSequenceUtils.toCharArray(null));
     }
-
-    static class WrapperString implements CharSequence {
-        private final CharSequence inner;
-
-        WrapperString(final CharSequence inner) {
-            this.inner = inner;
-        }
-
-        @Override
-        public int length() {
-            return inner.length();
-        }
-
-        @Override
-        public char charAt(final int index) {
-            return inner.charAt(index);
-        }
-
-        @Override
-        public CharSequence subSequence(final int start, final int end) {
-            return inner.subSequence(start, end);
-        }
-
-        @Override
-        public String toString() {
-            return inner.toString();
-        }
-
-        @Override
-        public IntStream chars() {
-            return inner.chars();
-        }
-
-        @Override
-        public IntStream codePoints() {
-            return inner.codePoints();
-        }
-    }
-
-    @Test
-    public void testNewLastIndexOf() {
-        testNewLastIndexOfSingle("808087847-1321060740-635567660180086727-925755305", "-1321060740-635567660", 21);
-        testNewLastIndexOfSingle("", "");
-        testNewLastIndexOfSingle("1", "");
-        testNewLastIndexOfSingle("", "1");
-        testNewLastIndexOfSingle("1", "1");
-        testNewLastIndexOfSingle("11", "1");
-        testNewLastIndexOfSingle("1", "11");
-
-        testNewLastIndexOfSingle("apache", "a");
-        testNewLastIndexOfSingle("apache", "p");
-        testNewLastIndexOfSingle("apache", "e");
-        testNewLastIndexOfSingle("apache", "x");
-        testNewLastIndexOfSingle("oraoraoraora", "r");
-        testNewLastIndexOfSingle("mudamudamudamuda", "d");
-
-        final Random random = new Random();
-        final StringBuilder seg = new StringBuilder();
-        while (seg.length() <= CharSequenceUtils.TO_STRING_LIMIT) {
-            seg.append(random.nextInt());
-        }
-        StringBuilder original = new StringBuilder(seg);
-        testNewLastIndexOfSingle(original, seg);
-        for (int i = 0; i < 100; i++) {
-            if (random.nextDouble() < 0.5) {
-                original.append(random.nextInt() % 10);
-            } else {
-                original = new StringBuilder().append(String.valueOf(random.nextInt() % 100)).append(original);
-            }
-            testNewLastIndexOfSingle(original, seg);
-        }
-    }
-
-    @ParameterizedTest
-    @MethodSource("lastIndexWithStandardCharSequence")
-    public void testLastIndexOfWithDifferentCharSequences(final CharSequence cs, final CharSequence search, final int start,
-                                                          final int expected) {
-        assertEquals(expected, CharSequenceUtils.lastIndexOf(cs, search, start));
-    }
-
-    static Stream<Arguments> lastIndexWithStandardCharSequence() {
-        return Stream.of(
-            arguments("abc", "b", 2, 1),
-            arguments(new StringBuilder("abc"), "b", 2, 1),
-            arguments(new StringBuffer("abc"), "b", 2, 1),
-            arguments("abc", new StringBuilder("b"), 2, 1),
-            arguments(new StringBuilder("abc"), new StringBuilder("b"), 2, 1),
-            arguments(new StringBuffer("abc"), new StringBuffer("b"), 2, 1),
-            arguments(new StringBuilder("abc"), new StringBuffer("b"), 2, 1)
-        );
-    }
-
-    private void testNewLastIndexOfSingle(final CharSequence a, final CharSequence b) {
-        final int maxa = Math.max(a.length(), b.length());
-        for (int i = -maxa - 10; i <= maxa + 10; i++) {
-            testNewLastIndexOfSingle(a, b, i);
-        }
-        testNewLastIndexOfSingle(a, b, Integer.MIN_VALUE);
-        testNewLastIndexOfSingle(a, b, Integer.MAX_VALUE);
-    }
-
-    private void testNewLastIndexOfSingle(final CharSequence a, final CharSequence b, final int start) {
-        testNewLastIndexOfSingleSingle(a, b, start);
-        testNewLastIndexOfSingleSingle(b, a, start);
-    }
-
-    private void testNewLastIndexOfSingleSingle(final CharSequence a, final CharSequence b, final int start) {
-        assertEquals(
-                a.toString().lastIndexOf(b.toString(), start),
-                CharSequenceUtils.lastIndexOf(new WrapperString(a.toString()), new WrapperString(b.toString()), start),
-                "testNewLastIndexOf fails! original : " + a + " seg : " + b + " start : " + start
-        );
-    }
 }
