@@ -41,108 +41,17 @@ import org.junit.jupiter.api.TestFactory;
 import org.junit.jupiter.api.function.Executable;
 import org.xml.sax.SAXException;
 
-public class StreamsTest {
-
-    @Test
-    public void testSimpleStreamMap() {
-        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-        final List<Integer> output = Functions.stream(input).map(Integer::valueOf).collect(Collectors.toList());
-        assertEquals(6, output.size());
-        for (int i = 0;  i < 6;  i++) {
-            assertEquals(i+1, output.get(i).intValue());
-        }
-    }
-
-    @Test
-    public void testSimpleStreamMapFailing() {
-        final List<String> input = Arrays.asList("1", "2", "3", "4 ", "5", "6");
-        final Executable testMethod = () -> Functions.stream(input).map(Integer::valueOf).collect(Collectors.toList());
-        final NumberFormatException thrown = assertThrows(NumberFormatException.class, testMethod);
-        assertEquals("For input string: \"4 \"", thrown.getMessage());
-    }
-
-    @Test
-    public void testSimpleStreamForEach() {
-        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-        final List<Integer> output = new ArrayList<>();
-        Functions.stream(input).forEach(s -> output.add(Integer.valueOf(s)));
-        assertEquals(6, output.size());
-        for (int i = 0;  i < 6;  i++) {
-            assertEquals(i+1, output.get(i).intValue());
-        }
-    }
-
-    @Test
-    public void testToArray() {
-        final String[] array = Arrays.asList("2", "3", "1").stream().collect(Streams.toArray(String.class));
-        assertNotNull(array);
-        assertEquals(3, array.length);
-        assertEquals("2", array[0]);
-        assertEquals("3", array[1]);
-        assertEquals("1", array[2]);
-    }
+public class StreamsTest extends AbstractLangTest {
 
     protected <T extends Throwable> FailableConsumer<String, T> asIntConsumer(final T pThrowable) {
         return s -> {
-            final Integer i = Integer.valueOf(s);
-            if (i.intValue() == 4) {
+            final int i = Integer.parseInt(s);
+            if (i == 4) {
                 throw pThrowable;
             }
         };
     }
 
-    @TestFactory
-    public Stream<DynamicTest> simpleStreamForEachFailing() {
-        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-
-        return Stream.of(
-
-                dynamicTest("IllegalArgumentException", () -> {
-                    final IllegalArgumentException ise = new IllegalArgumentException();
-                    final Executable testMethod = () -> Functions.stream(input)
-                            .forEach(asIntConsumer(ise));
-                    final IllegalArgumentException thrown = assertThrows(IllegalArgumentException.class, testMethod);
-                    assertThat(thrown.getMessage(), is(nullValue()));
-                }),
-
-                dynamicTest("OutOfMemoryError", () -> {
-                    final OutOfMemoryError oome = new OutOfMemoryError();
-                    final Executable oomeTestMethod = () -> Functions.stream(input)
-                            .forEach(asIntConsumer(oome));
-                    final OutOfMemoryError oomeThrown = assertThrows(OutOfMemoryError.class, oomeTestMethod);
-                    assertThat(oomeThrown.getMessage(), is(nullValue()));
-                }),
-
-                dynamicTest("SAXException", () -> {
-                    final SAXException se = new SAXException();
-                    final Executable seTestMethod = () -> Functions.stream(input)
-                            .forEach(asIntConsumer(se));
-                    final UndeclaredThrowableException seThrown = assertThrows(UndeclaredThrowableException.class, seTestMethod);
-                    assertAll(
-                            () -> assertThat(seThrown.getMessage(), is(nullValue())),
-                            () -> assertThat(seThrown.getCause(), is(equalTo(se)))
-                    );
-                })
-        );
-    }
-
-    @Test
-    public void testSimpleStreamFilter() {
-        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-        final List<Integer> output = Functions.stream(input)
-                .map(Integer::valueOf)
-                .filter(i -> (i.intValue() %2 == 0))
-                .collect(Collectors.toList());
-        assertEvenNumbers(output);
-    }
-
-    private void assertEvenNumbers(final List<Integer> output) {
-        assertEquals(3, output.size());
-        for (int i = 0;  i < 3;  i++) {
-            assertEquals((i+1)*2, output.get(i).intValue());
-        }
-    }
-
     protected <T extends Throwable> FailablePredicate<Integer, T> asIntPredicate(final T pThrowable) {
         return i -> {
             if (i.intValue() == 5 && pThrowable != null) {
@@ -152,6 +61,13 @@ public class StreamsTest {
         };
     }
 
+    private void assertEvenNumbers(final List<Integer> output) {
+        assertEquals(3, output.size());
+        for (int i = 0;  i < 3;  i++) {
+            assertEquals((i+1)*2, output.get(i).intValue());
+        }
+    }
+
     @TestFactory
     public Stream<DynamicTest> simpleStreamFilterFailing() {
         final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
@@ -198,4 +114,88 @@ public class StreamsTest {
         );
     }
 
+    @TestFactory
+    public Stream<DynamicTest> simpleStreamForEachFailing() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
+
+        return Stream.of(
+
+                dynamicTest("IllegalArgumentException", () -> {
+                    final IllegalArgumentException ise = new IllegalArgumentException();
+                    final Executable testMethod = () -> Functions.stream(input)
+                            .forEach(asIntConsumer(ise));
+                    final IllegalArgumentException thrown = assertThrows(IllegalArgumentException.class, testMethod);
+                    assertThat(thrown.getMessage(), is(nullValue()));
+                }),
+
+                dynamicTest("OutOfMemoryError", () -> {
+                    final OutOfMemoryError oome = new OutOfMemoryError();
+                    final Executable oomeTestMethod = () -> Functions.stream(input)
+                            .forEach(asIntConsumer(oome));
+                    final OutOfMemoryError oomeThrown = assertThrows(OutOfMemoryError.class, oomeTestMethod);
+                    assertThat(oomeThrown.getMessage(), is(nullValue()));
+                }),
+
+                dynamicTest("SAXException", () -> {
+                    final SAXException se = new SAXException();
+                    final Executable seTestMethod = () -> Functions.stream(input)
+                            .forEach(asIntConsumer(se));
+                    final UndeclaredThrowableException seThrown = assertThrows(UndeclaredThrowableException.class, seTestMethod);
+                    assertAll(
+                            () -> assertThat(seThrown.getMessage(), is(nullValue())),
+                            () -> assertThat(seThrown.getCause(), is(equalTo(se)))
+                    );
+                })
+        );
+    }
+
+    @Test
+    public void testSimpleStreamFilter() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
+        final List<Integer> output = Functions.stream(input)
+                .map(Integer::valueOf)
+                .filter(i -> (i.intValue() %2 == 0))
+                .collect(Collectors.toList());
+        assertEvenNumbers(output);
+    }
+
+    @Test
+    public void testSimpleStreamForEach() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
+        final List<Integer> output = new ArrayList<>();
+        Functions.stream(input).forEach(s -> output.add(Integer.valueOf(s)));
+        assertEquals(6, output.size());
+        for (int i = 0;  i < 6;  i++) {
+            assertEquals(i+1, output.get(i).intValue());
+        }
+    }
+
+    @Test
+    public void testSimpleStreamMap() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
+        final List<Integer> output = Functions.stream(input).map(Integer::valueOf).collect(Collectors.toList());
+        assertEquals(6, output.size());
+        for (int i = 0;  i < 6;  i++) {
+            assertEquals(i+1, output.get(i).intValue());
+        }
+    }
+
+    @Test
+    public void testSimpleStreamMapFailing() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4 ", "5", "6");
+        final Executable testMethod = () -> Functions.stream(input).map(Integer::valueOf).collect(Collectors.toList());
+        final NumberFormatException thrown = assertThrows(NumberFormatException.class, testMethod);
+        assertEquals("For input string: \"4 \"", thrown.getMessage());
+    }
+
+    @Test
+    public void testToArray() {
+        final String[] array = Arrays.asList("2", "3", "1").stream().collect(Streams.toArray(String.class));
+        assertNotNull(array);
+        assertEquals(3, array.length);
+        assertEquals("2", array[0]);
+        assertEquals("3", array[1]);
+        assertEquals("1", array[2]);
+    }
+
 }
