@@ -21,30 +21,136 @@ import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assertions.fail;
 
 import java.util.Iterator;
 import java.util.NoSuchElementException;
+import java.util.concurrent.CountDownLatch;
 import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.TimeUnit;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.BeforeEach;
 import org.junit.jupiter.api.Test;
 
 /**
  * Test class for {@link MultiBackgroundInitializer}.
  */
-public class MultiBackgroundInitializerTest {
+public class MultiBackgroundInitializerTest extends AbstractLangTest {
+    /**
+     * A mostly complete implementation of {@code BackgroundInitializer} used for
+     * defining background tasks for {@code MultiBackgroundInitializer}.
+     *
+     * Subclasses will contain the initializer, either as an method implementation
+     * or by using a supplier.
+     */
+    protected static class AbstractChildBackgroundInitializer extends BackgroundInitializer<CloseableCounter> {
+        /** Stores the current executor service. */
+        volatile ExecutorService currentExecutor;
+
+        /** An object containing the state we are testing */
+        CloseableCounter counter = new CloseableCounter();
+
+        /** A counter for the invocations of initialize(). */
+        volatile int initializeCalls;
+
+        /** An exception to be thrown by initialize(). */
+        Exception ex;
+
+        /** A latch tests can use to control when initialize completes. */
+        final CountDownLatch latch = new CountDownLatch(1);
+        boolean waitForLatch;
+
+        public void enableLatch() {
+            waitForLatch = true;
+        }
+
+        public CloseableCounter getCloseableCounter() {
+            return counter;
+        }
+
+        /**
+         * Records this invocation. Optionally throws an exception.
+         */
+        protected CloseableCounter initializeInternal() throws Exception {
+            initializeCalls++;
+            currentExecutor = getActiveExecutor();
+
+            if (waitForLatch) {
+                latch.await();
+            }
+
+            if (ex != null) {
+                throw ex;
+            }
+
+            return counter.increment();
+        }
+
+        public void releaseLatch() {
+            latch.countDown();
+        }
+    }
+
+    protected static class CloseableCounter {
+        // A convenience for testing that a CloseableCounter typed as Object has a specific initializeCalls value
+        public static CloseableCounter wrapInteger(int i) {
+            return new CloseableCounter().setInitializeCalls(i);
+        }
+
+        /** The number of invocations of initialize(). */
+        volatile int initializeCalls;
+
+        /** Has the close consumer successfully reached this object. */
+        volatile boolean closed;
+
+        public void close() {
+            closed = true;
+        }
+
+        @Override
+        public boolean equals(final Object other) {
+            if (other instanceof CloseableCounter) {
+                return initializeCalls == ((CloseableCounter) other).getInitializeCalls();
+            }
+            return false;
+        }
+
+        public int getInitializeCalls() {
+            return initializeCalls;
+        }
+
+        public CloseableCounter increment() {
+            initializeCalls++;
+            return this;
+        }
+
+        public boolean isClosed() {
+            return closed;
+        }
+
+        public CloseableCounter setInitializeCalls(int i) {
+            initializeCalls = i;
+            return this;
+        }
+    }
+
+    protected static class MethodChildBackgroundInitializer extends AbstractChildBackgroundInitializer {
+        @Override
+        protected CloseableCounter initialize() throws Exception {
+            return initializeInternal();
+        }
+    }
+
     /** Constant for the names of the child initializers. */
     private static final String CHILD_INIT = "childInitializer";
 
-    /** The initializer to be tested. */
-    private MultiBackgroundInitializer initializer;
+    /** A short time to wait for background threads to run. */
+    protected static final long PERIOD_MILLIS = 50;
 
-    @BeforeEach
-    public void setUp() {
-        initializer = new MultiBackgroundInitializer();
-    }
+    /** The initializer to be tested. */
+    protected MultiBackgroundInitializer initializer;
 
     /**
      * Tests whether a child initializer has been executed. Optionally the
@@ -57,8 +163,8 @@ public class MultiBackgroundInitializerTest {
      */
     private void checkChild(final BackgroundInitializer<?> child,
             final ExecutorService expExec) throws ConcurrentException {
-        final ChildBackgroundInitializer cinit = (ChildBackgroundInitializer) child;
-        final Integer result = cinit.get();
+        final AbstractChildBackgroundInitializer cinit = (AbstractChildBackgroundInitializer) child;
+        final Integer result = cinit.get().getInitializeCalls();
         assertEquals(1, result.intValue(), "Wrong result");
         assertEquals(1, cinit.initializeCalls, "Wrong number of executions");
         if (expExec != null) {
@@ -66,38 +172,6 @@ public class MultiBackgroundInitializerTest {
         }
     }
 
-    /**
-     * Tests addInitializer() if a null name is passed in. This should cause an
-     * exception.
-     */
-    @Test
-    public void testAddInitializerNullName() {
-        assertThrows(NullPointerException.class, () -> initializer.addInitializer(null, new ChildBackgroundInitializer()));
-    }
-
-    /**
-     * Tests addInitializer() if a null initializer is passed in. This should
-     * cause an exception.
-     */
-    @Test
-    public void testAddInitializerNullInit() {
-        assertThrows(NullPointerException.class, () -> initializer.addInitializer(CHILD_INIT, null));
-    }
-
-    /**
-     * Tests the background processing if there are no child initializers.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeNoChildren() throws ConcurrentException {
-        assertTrue(initializer.start(), "Wrong result of start()");
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
-                .get();
-        assertTrue(res.initializerNames().isEmpty(), "Got child initializers");
-        assertTrue(initializer.getActiveExecutor().isShutdown(), "Executor not shutdown");
-    }
-
     /**
      * Helper method for testing the initialize() method. This method can
      * operate with both an external and a temporary executor service.
@@ -111,7 +185,7 @@ public class MultiBackgroundInitializerTest {
         final int count = 5;
         for (int i = 0; i < count; i++) {
             initializer.addInitializer(CHILD_INIT + i,
-                    new ChildBackgroundInitializer());
+                    createChildBackgroundInitializer());
         }
         initializer.start();
         final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
@@ -120,7 +194,7 @@ public class MultiBackgroundInitializerTest {
         for (int i = 0; i < count; i++) {
             final String key = CHILD_INIT + i;
             assertTrue(res.initializerNames().contains(key), "Name not found: " + key);
-            assertEquals(Integer.valueOf(1), res.getResultObject(key), "Wrong result object");
+            assertEquals(CloseableCounter.wrapInteger(1), res.getResultObject(key), "Wrong result object");
             assertFalse(res.isException(key), "Exception flag");
             assertNull(res.getException(key), "Got an exception");
             checkChild(res.getInitializer(key), initializer.getActiveExecutor());
@@ -129,14 +203,97 @@ public class MultiBackgroundInitializerTest {
     }
 
     /**
-     * Tests background processing if a temporary executor is used.
+     * An overrideable method to create concrete implementations of
+     * {@code BackgroundInitializer} used for defining background tasks
+     * for {@code MultiBackgroundInitializer}.
+     */
+    protected AbstractChildBackgroundInitializer createChildBackgroundInitializer() {
+        return new MethodChildBackgroundInitializer();
+    }
+
+    @BeforeEach
+    public void setUp() {
+        initializer = new MultiBackgroundInitializer();
+    }
+
+    /**
+     * Tries to add another child initializer after the start() method has been
+     * called. This should not be allowed.
      *
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testInitializeTempExec() throws ConcurrentException {
-        checkInitialize();
-        assertTrue(initializer.getActiveExecutor().isShutdown(), "Executor not shutdown");
+    public void testAddInitializerAfterStart() throws ConcurrentException {
+        initializer.start();
+        assertThrows(
+                IllegalStateException.class,
+                () -> initializer.addInitializer(CHILD_INIT, createChildBackgroundInitializer()),
+                "Could add initializer after start()!");
+        initializer.get();
+    }
+
+    /**
+     * Tests addInitializer() if a null initializer is passed in. This should
+     * cause an exception.
+     */
+    @Test
+    public void testAddInitializerNullInit() {
+        assertThrows(NullPointerException.class, () -> initializer.addInitializer(CHILD_INIT, null));
+    }
+
+    /**
+     * Tests addInitializer() if a null name is passed in. This should cause an
+     * exception.
+     */
+    @Test
+    public void testAddInitializerNullName() {
+        assertThrows(NullPointerException.class, () -> initializer.addInitializer(null, createChildBackgroundInitializer()));
+    }
+
+    /**
+     * Tests the behavior of initialize() if a child initializer has a specific
+     * executor service. Then this service should not be overridden.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeChildWithExecutor() throws ConcurrentException, InterruptedException {
+        final String initExec = "childInitializerWithExecutor";
+        final ExecutorService exec = Executors.newSingleThreadExecutor();
+        try {
+            final AbstractChildBackgroundInitializer c1 = createChildBackgroundInitializer();
+            final AbstractChildBackgroundInitializer c2 = createChildBackgroundInitializer();
+            c2.setExternalExecutor(exec);
+            initializer.addInitializer(CHILD_INIT, c1);
+            initializer.addInitializer(initExec, c2);
+            initializer.start();
+            initializer.get();
+            checkChild(c1, initializer.getActiveExecutor());
+            checkChild(c2, exec);
+        } finally {
+            exec.shutdown();
+            exec.awaitTermination(1, TimeUnit.SECONDS);
+        }
+    }
+
+    /**
+     * Tests the behavior of the initializer if one of the child initializers
+     * throws a checked exception.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeEx() throws ConcurrentException {
+        final AbstractChildBackgroundInitializer child = createChildBackgroundInitializer();
+        child.ex = new Exception();
+        initializer.addInitializer(CHILD_INIT, child);
+        initializer.start();
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
+                .get();
+        assertTrue(res.isException(CHILD_INIT), "No exception flag");
+        assertNull(res.getResultObject(CHILD_INIT), "Got a results object");
+        final ConcurrentException cex = res.getException(CHILD_INIT);
+        assertEquals(child.ex, cex.getCause(), "Wrong cause");
     }
 
     /**
@@ -159,45 +316,159 @@ public class MultiBackgroundInitializerTest {
     }
 
     /**
-     * Tests the behavior of initialize() if a child initializer has a specific
-     * executor service. Then this service should not be overridden.
+     * Tests whether MultiBackgroundInitializers can be combined in a nested
+     * way.
      *
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testInitializeChildWithExecutor() throws ConcurrentException, InterruptedException {
-        final String initExec = "childInitializerWithExecutor";
-        final ExecutorService exec = Executors.newSingleThreadExecutor();
-        try {
-            final ChildBackgroundInitializer c1 = new ChildBackgroundInitializer();
-            final ChildBackgroundInitializer c2 = new ChildBackgroundInitializer();
-            c2.setExternalExecutor(exec);
-            initializer.addInitializer(CHILD_INIT, c1);
-            initializer.addInitializer(initExec, c2);
-            initializer.start();
-            initializer.get();
-            checkChild(c1, initializer.getActiveExecutor());
-            checkChild(c2, exec);
-        } finally {
-            exec.shutdown();
-            exec.awaitTermination(1, TimeUnit.SECONDS);
+    public void testInitializeNested() throws ConcurrentException {
+        final String nameMulti = "multiChildInitializer";
+        initializer
+                .addInitializer(CHILD_INIT, createChildBackgroundInitializer());
+        final MultiBackgroundInitializer mi2 = new MultiBackgroundInitializer();
+        final int count = 3;
+        for (int i = 0; i < count; i++) {
+            mi2
+                    .addInitializer(CHILD_INIT + i,
+                            createChildBackgroundInitializer());
         }
+        initializer.addInitializer(nameMulti, mi2);
+        initializer.start();
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
+                .get();
+        final ExecutorService exec = initializer.getActiveExecutor();
+        checkChild(res.getInitializer(CHILD_INIT), exec);
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res2 = (MultiBackgroundInitializer.MultiBackgroundInitializerResults) res
+                .getResultObject(nameMulti);
+        assertEquals(count, res2.initializerNames().size(), "Wrong number of initializers");
+        for (int i = 0; i < count; i++) {
+            checkChild(res2.getInitializer(CHILD_INIT + i), exec);
+        }
+        assertTrue(exec.isShutdown(), "Executor not shutdown");
     }
 
     /**
-     * Tries to add another child initializer after the start() method has been
-     * called. This should not be allowed.
+     * Tests the background processing if there are no child initializers.
      *
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testAddInitializerAfterStart() throws ConcurrentException {
+    public void testInitializeNoChildren() throws ConcurrentException {
+        assertTrue(initializer.start(), "Wrong result of start()");
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
+                .get();
+        assertTrue(res.initializerNames().isEmpty(), "Got child initializers");
+        assertTrue(initializer.getActiveExecutor().isShutdown(), "Executor not shutdown");
+    }
+
+    /**
+     * Tests the isSuccessful() method of the result object if at least one
+     * child initializer has thrown an exception.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeResultsIsSuccessfulFalse()
+            throws ConcurrentException {
+        final AbstractChildBackgroundInitializer child = createChildBackgroundInitializer();
+        child.ex = new Exception();
+        initializer.addInitializer(CHILD_INIT, child);
         initializer.start();
-        assertThrows(
-                IllegalStateException.class,
-                () -> initializer.addInitializer(CHILD_INIT, new ChildBackgroundInitializer()),
-                "Could add initializer after start()!");
-        initializer.get();
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
+                .get();
+        assertFalse(res.isSuccessful(), "Wrong success flag");
+    }
+
+    /**
+     * Tests the isSuccessful() method of the result object if no child
+     * initializer has thrown an exception.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeResultsIsSuccessfulTrue()
+            throws ConcurrentException {
+        final AbstractChildBackgroundInitializer child = createChildBackgroundInitializer();
+        initializer.addInitializer(CHILD_INIT, child);
+        initializer.start();
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
+                .get();
+        assertTrue(res.isSuccessful(), "Wrong success flag");
+    }
+
+    /**
+     * Tests the behavior of the initializer if one of the child initializers
+     * throws a runtime exception.
+     */
+    @Test
+    public void testInitializeRuntimeEx() {
+        final AbstractChildBackgroundInitializer child = createChildBackgroundInitializer();
+        child.ex = new RuntimeException();
+        initializer.addInitializer(CHILD_INIT, child);
+        initializer.start();
+        final Exception ex = assertThrows(Exception.class, initializer::get);
+        assertEquals(child.ex, ex, "Wrong exception");
+    }
+
+    /**
+     * Tests background processing if a temporary executor is used.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testInitializeTempExec() throws ConcurrentException {
+        checkInitialize();
+        assertTrue(initializer.getActiveExecutor().isShutdown(), "Executor not shutdown");
+    }
+
+    @Test
+    public void testIsInitialized()
+            throws ConcurrentException, InterruptedException {
+        final AbstractChildBackgroundInitializer childOne = createChildBackgroundInitializer();
+        final AbstractChildBackgroundInitializer childTwo = createChildBackgroundInitializer();
+
+        childOne.enableLatch();
+        childTwo.enableLatch();
+
+        assertFalse(initializer.isInitialized(), "Initalized without having anything to initalize");
+
+        initializer.addInitializer("child one", childOne);
+        initializer.addInitializer("child two", childTwo);
+        initializer.start();
+
+        long startTime = System.currentTimeMillis();
+        long waitTime = 3000;
+        long endTime = startTime + waitTime;
+        //wait for the children to start
+        while (! childOne.isStarted() || ! childTwo.isStarted()) {
+            if (System.currentTimeMillis() > endTime) {
+                fail("children never started");
+                Thread.sleep(PERIOD_MILLIS);
+            }
+        }
+
+        assertFalse(initializer.isInitialized(), "Initalized with two children running");
+
+        childOne.releaseLatch();
+        childOne.get(); //ensure this child finishes initializing
+        assertFalse(initializer.isInitialized(), "Initalized with one child running");
+
+        childTwo.releaseLatch();
+        childTwo.get(); //ensure this child finishes initializing
+        assertTrue(initializer.isInitialized(), "Not initalized with no children running");
+    }
+
+    /**
+     * Tries to query the exception of an unknown child initializer from the
+     * results object. This should cause an exception.
+     *
+     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
+     */
+    @Test
+    public void testResultGetExceptionUnknown() throws ConcurrentException {
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = checkInitialize();
+        assertThrows(NoSuchElementException.class, () -> res.getException("unknown"));
     }
 
     /**
@@ -224,30 +495,6 @@ public class MultiBackgroundInitializerTest {
         assertThrows(NoSuchElementException.class, () -> res.getResultObject("unknown"));
     }
 
-    /**
-     * Tries to query the exception of an unknown child initializer from the
-     * results object. This should cause an exception.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testResultGetExceptionUnknown() throws ConcurrentException {
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = checkInitialize();
-        assertThrows(NoSuchElementException.class, () -> res.getException("unknown"));
-    }
-
-    /**
-     * Tries to query the exception flag of an unknown child initializer from
-     * the results object. This should cause an exception.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testResultIsExceptionUnknown() throws ConcurrentException {
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = checkInitialize();
-        assertThrows(NoSuchElementException.class, () -> res.isException("unknown"));
-    }
-
     /**
      * Tests that the set with the names of the initializers cannot be modified.
      *
@@ -264,135 +511,14 @@ public class MultiBackgroundInitializerTest {
     }
 
     /**
-     * Tests the behavior of the initializer if one of the child initializers
-     * throws a runtime exception.
-     */
-    @Test
-    public void testInitializeRuntimeEx() {
-        final ChildBackgroundInitializer child = new ChildBackgroundInitializer();
-        child.ex = new RuntimeException();
-        initializer.addInitializer(CHILD_INIT, child);
-        initializer.start();
-        final Exception ex = assertThrows(Exception.class, initializer::get);
-        assertEquals(child.ex, ex, "Wrong exception");
-    }
-
-    /**
-     * Tests the behavior of the initializer if one of the child initializers
-     * throws a checked exception.
+     * Tries to query the exception flag of an unknown child initializer from
+     * the results object. This should cause an exception.
      *
      * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
      */
     @Test
-    public void testInitializeEx() throws ConcurrentException {
-        final ChildBackgroundInitializer child = new ChildBackgroundInitializer();
-        child.ex = new Exception();
-        initializer.addInitializer(CHILD_INIT, child);
-        initializer.start();
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
-                .get();
-        assertTrue(res.isException(CHILD_INIT), "No exception flag");
-        assertNull(res.getResultObject(CHILD_INIT), "Got a results object");
-        final ConcurrentException cex = res.getException(CHILD_INIT);
-        assertEquals(child.ex, cex.getCause(), "Wrong cause");
-    }
-
-    /**
-     * Tests the isSuccessful() method of the result object if no child
-     * initializer has thrown an exception.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeResultsIsSuccessfulTrue()
-            throws ConcurrentException {
-        final ChildBackgroundInitializer child = new ChildBackgroundInitializer();
-        initializer.addInitializer(CHILD_INIT, child);
-        initializer.start();
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
-                .get();
-        assertTrue(res.isSuccessful(), "Wrong success flag");
-    }
-
-    /**
-     * Tests the isSuccessful() method of the result object if at least one
-     * child initializer has thrown an exception.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeResultsIsSuccessfulFalse()
-            throws ConcurrentException {
-        final ChildBackgroundInitializer child = new ChildBackgroundInitializer();
-        child.ex = new Exception();
-        initializer.addInitializer(CHILD_INIT, child);
-        initializer.start();
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
-                .get();
-        assertFalse(res.isSuccessful(), "Wrong success flag");
-    }
-
-    /**
-     * Tests whether MultiBackgroundInitializers can be combined in a nested
-     * way.
-     *
-     * @throws org.apache.commons.lang3.concurrent.ConcurrentException so we don't have to catch it
-     */
-    @Test
-    public void testInitializeNested() throws ConcurrentException {
-        final String nameMulti = "multiChildInitializer";
-        initializer
-                .addInitializer(CHILD_INIT, new ChildBackgroundInitializer());
-        final MultiBackgroundInitializer mi2 = new MultiBackgroundInitializer();
-        final int count = 3;
-        for (int i = 0; i < count; i++) {
-            mi2
-                    .addInitializer(CHILD_INIT + i,
-                            new ChildBackgroundInitializer());
-        }
-        initializer.addInitializer(nameMulti, mi2);
-        initializer.start();
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = initializer
-                .get();
-        final ExecutorService exec = initializer.getActiveExecutor();
-        checkChild(res.getInitializer(CHILD_INIT), exec);
-        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res2 = (MultiBackgroundInitializer.MultiBackgroundInitializerResults) res
-                .getResultObject(nameMulti);
-        assertEquals(count, res2.initializerNames().size(), "Wrong number of initializers");
-        for (int i = 0; i < count; i++) {
-            checkChild(res2.getInitializer(CHILD_INIT + i), exec);
-        }
-        assertTrue(exec.isShutdown(), "Executor not shutdown");
-    }
-
-    /**
-     * A concrete implementation of {@code BackgroundInitializer} used for
-     * defining background tasks for {@code MultiBackgroundInitializer}.
-     */
-    private static class ChildBackgroundInitializer extends
-            BackgroundInitializer<Integer> {
-        /** Stores the current executor service. */
-        volatile ExecutorService currentExecutor;
-
-        /** A counter for the invocations of initialize(). */
-        volatile int initializeCalls;
-
-        /** An exception to be thrown by initialize(). */
-        Exception ex;
-
-        /**
-         * Records this invocation. Optionally throws an exception.
-         */
-        @Override
-        protected Integer initialize() throws Exception {
-            currentExecutor = getActiveExecutor();
-            initializeCalls++;
-
-            if (ex != null) {
-                throw ex;
-            }
-
-            return Integer.valueOf(initializeCalls);
-        }
+    public void testResultIsExceptionUnknown() throws ConcurrentException {
+        final MultiBackgroundInitializer.MultiBackgroundInitializerResults res = checkInitialize();
+        assertThrows(NoSuchElementException.class, () -> res.isException("unknown"));
     }
 }
