@@ -21,6 +21,7 @@ import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
 import static org.junit.jupiter.api.Assertions.assertSame;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 
 
@@ -29,9 +30,8 @@ import org.junit.jupiter.api.Test;
  *
  * @see MutableShort
  */
-public class MutableObjectTest {
+public class MutableObjectTest extends AbstractLangTest {
 
-    // ----------------------------------------------------------------
     @Test
     public void testConstructors() {
         assertNull(new MutableObject<String>().getValue());
@@ -47,7 +47,8 @@ public class MutableObjectTest {
         final MutableObject<String> mutNumA = new MutableObject<>("ALPHA");
         final MutableObject<String> mutNumB = new MutableObject<>("ALPHA");
         final MutableObject<String> mutNumC = new MutableObject<>("BETA");
-        final MutableObject<String> mutNumD = new MutableObject<>(null);
+        final MutableObject<String> mutNumNull1 = new MutableObject<>(null);
+        final MutableObject<String> mutNumNull2 = new MutableObject<>(null);
 
         assertEquals(mutNumA, mutNumA);
         assertEquals(mutNumA, mutNumB);
@@ -56,8 +57,10 @@ public class MutableObjectTest {
         assertNotEquals(mutNumA, mutNumC);
         assertNotEquals(mutNumB, mutNumC);
         assertEquals(mutNumC, mutNumC);
-        assertNotEquals(mutNumA, mutNumD);
-        assertEquals(mutNumD, mutNumD);
+        assertNotEquals(mutNumA, mutNumNull1);
+        assertEquals(mutNumNull1, mutNumNull1);
+        assertEquals(mutNumNull1, mutNumNull2);
+        assertEquals(mutNumNull2, mutNumNull1);
 
         assertNotEquals(null, mutNumA);
         assertNotEquals(mutNumA, new Object());
