@@ -20,7 +20,9 @@ import static org.junit.jupiter.api.Assertions.assertArrayEquals;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertFalse;
 import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 import static org.junit.jupiter.api.Assertions.assertTrue;
+import static org.junit.jupiter.api.Assumptions.assumeTrue;
 
 import java.awt.Insets;
 import java.io.Serializable;
@@ -34,14 +36,19 @@ import java.lang.reflect.TypeVariable;
 import java.lang.reflect.WildcardType;
 import java.net.URI;
 import java.util.ArrayList;
+import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.Comparator;
 import java.util.HashMap;
 import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.TreeSet;
 
+import org.apache.commons.lang3.AbstractLangTest;
+import org.apache.commons.lang3.JavaVersion;
+import org.apache.commons.lang3.SystemUtils;
 import org.apache.commons.lang3.reflect.testbed.Foo;
 import org.apache.commons.lang3.reflect.testbed.GenericParent;
 import org.apache.commons.lang3.reflect.testbed.GenericTypeHolder;
@@ -49,40 +56,55 @@ import org.apache.commons.lang3.reflect.testbed.StringParameterizedChild;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
-class AAAClass extends AAClass<String> {
+final class AAAClass extends AAClass<String> {
     public class BBBClass extends BBClass<String> {
+        // empty
     }
 }
 
+@SuppressWarnings("unused") // Unused type parameter for test
 class AAClass<T> {
 
     public class BBClass<S> {
+        // empty
     }
 }
 
 @SuppressWarnings("rawtypes")
 //raw types, where used, are used purposely
-class AClass extends AAClass<String>.BBClass<Number> {
+final class AClass extends AAClass<String>.BBClass<Number> {
 
+    @SuppressWarnings("unused") // Unused type parameter for test
     public interface AInterface<T> {
+        // empty
     }
 
+    @SuppressWarnings("unused") // Unused type parameter for test
     public class BClass<T> {
+        // empty
     }
 
+    @SuppressWarnings("unused") // Unused type parameter for test
     public class CClass<T> extends BClass {
+        // empty
     }
 
+    @SuppressWarnings("unused") // Unused type parameter for test
     public class DClass<T> extends CClass<T> {
+        // empty
     }
 
+    @SuppressWarnings("unused") // Unused type parameter for test
     public class EClass<T> extends DClass {
+        // empty
     }
 
     public class FClass extends EClass<String> {
+        // empty
     }
 
     public class GClass<T extends BClass<? extends T> & AInterface<AInterface<? super T>>> {
+        // empty
     }
 
     public BClass<Number> bClass;
@@ -105,14 +127,6 @@ class AClass extends AAClass<String>.BBClass<Number> {
 abstract class Test1<G> {
     public abstract Object m0();
     public abstract String[] m1();
-    public abstract <E> E[] m2();
-    public abstract <E> List<? extends E> m3();
-    public abstract <E extends Enum<E>> List<? extends Enum<E>> m4();
-    public abstract List<? extends Enum<?>> m5();
-    public abstract List<? super Enum<?>> m6();
-    public abstract List<?> m7();
-    public abstract Map<? extends Enum<?>, ? super Enum<?>> m8();
-    public abstract <K, V> Map<? extends K, ? super V[]> m9();
     public abstract <K, V> Map<? extends K, V[]> m10();
     public abstract <K, V> Map<? extends K, List<V[]>> m11();
     public abstract List m12();
@@ -121,6 +135,14 @@ abstract class Test1<G> {
     public abstract G m15();
     public abstract List<G> m16();
     public abstract Enum m17();
+    public abstract <E> E[] m2();
+    public abstract <E> List<? extends E> m3();
+    public abstract <E extends Enum<E>> List<? extends Enum<E>> m4();
+    public abstract List<? extends Enum<?>> m5();
+    public abstract List<? super Enum<?>> m6();
+    public abstract List<?> m7();
+    public abstract Map<? extends Enum<?>, ? super Enum<?>> m8();
+    public abstract <K, V> Map<? extends K, ? super V[]> m9();
 }
 
 /**
@@ -128,7 +150,7 @@ abstract class Test1<G> {
  */
 @SuppressWarnings({ "unchecked", "unused", "rawtypes" })
 //raw types, where used, are used purposely
-public class TypeUtilsTest<B> {
+public class TypeUtilsTest<B> extends AbstractLangTest {
 
     public interface And<K, V> extends This<Number, Number> {
     }
@@ -232,6 +254,67 @@ public class TypeUtilsTest<B> {
             final List<? super String>[] list13) {
     }
 
+    @Test
+    public void test_LANG_1114() throws Exception {
+        final Type nonWildcardType = getClass().getDeclaredField("wildcardComparable").getGenericType();
+        final Type wildcardType = ((ParameterizedType) nonWildcardType).getActualTypeArguments()[0];
+
+        assertFalse(TypeUtils.equals(wildcardType, nonWildcardType));
+        assertFalse(TypeUtils.equals(nonWildcardType, wildcardType));
+    }
+
+    @Test
+    public void test_LANG_1190() throws Exception {
+        final Type fromType = ClassWithSuperClassWithGenericType.class.getDeclaredMethod("methodWithGenericReturnType").getGenericReturnType();
+        final Type failingToType = TypeUtils.wildcardType().withLowerBounds(ClassWithSuperClassWithGenericType.class).build();
+
+        assertTrue(TypeUtils.isAssignable(fromType, failingToType));
+    }
+
+    @Test
+    public void test_LANG_1348() throws Exception {
+        final Method method = Enum.class.getMethod("valueOf", Class.class, String.class);
+        assertEquals("T extends java.lang.Enum<T>", TypeUtils.toString(method.getGenericReturnType()));
+    }
+
+    /**
+     * <pre>{@code
+     * java.lang.StackOverflowError
+    at org.apache.commons.lang3.reflect.TypeUtils.typeVariableToString(TypeUtils.java:1785)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1737)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1714)
+    at org.apache.commons.lang3.reflect.TypeUtils.appendAllTo(TypeUtils.java:302)
+    at org.apache.commons.lang3.reflect.TypeUtils.wildcardTypeToString(TypeUtils.java:1902)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1734)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1714)
+    at org.apache.commons.lang3.reflect.TypeUtils.appendAllTo(TypeUtils.java:302)
+    at org.apache.commons.lang3.reflect.TypeUtils.parameterizedTypeToString(TypeUtils.java:1604)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1731)
+    at org.apache.commons.lang3.reflect.TypeUtils.toString(TypeUtils.java:1714)
+    at org.apache.commons.lang3.reflect.TypeUtils.appendAllTo(TypeUtils.java:302)
+    at org.apache.commons.lang3.reflect.TypeUtils.typeVariableToString(TypeUtils.java:1789)
+     * }
+     * </pre>
+     */
+    @Test
+    public void test_LANG_1698() {
+        // SO on Java 17
+        assumeTrue(SystemUtils.isJavaVersionAtMost(JavaVersion.JAVA_16));
+        final ParameterizedType comparing = (ParameterizedType) Arrays.stream(Comparator.class.getDeclaredMethods())
+                .filter(k -> k.getName().equals("comparing")).findFirst()
+                .orElse(Comparator.class.getDeclaredMethods()[0]).getGenericParameterTypes()[0];
+        final String typeName = TypeUtils
+                .parameterize((Class<?>) comparing.getRawType(), comparing.getActualTypeArguments()).getTypeName();
+        assertEquals("java.util.function.Function<? super T, ? extends U>", typeName);
+    }
+
+    @Test
+    public void test_LANG_820() {
+        final Type[] typeArray = {String.class, String.class};
+        final Type[] expectedArray = {String.class};
+        assertArrayEquals(expectedArray, TypeUtils.normalizeUpperBounds(typeArray));
+    }
+
     @Test
     public void testContainsTypeVariables() throws Exception {
         assertFalse(TypeUtils.containsTypeVariables(Test1.class.getMethod("m0").getGenericReturnType()));
@@ -265,6 +348,11 @@ public class TypeUtilsTest<B> {
         assertTrue(typeVarAssigns.containsKey(treeSetTypeVar));
         assertEquals(iterableType.getActualTypeArguments()[0], typeVarAssigns
                 .get(treeSetTypeVar));
+
+        assertThrows(NullPointerException.class,
+                () -> TypeUtils.determineTypeArguments(TreeSet.class, null));
+        assertThrows(NullPointerException.class,
+                () -> TypeUtils.determineTypeArguments(null, iterableType));
     }
 
     @Test
@@ -324,27 +412,33 @@ public class TypeUtilsTest<B> {
 
     @Test
     public void testGetRawType() throws SecurityException, NoSuchFieldException {
-        final Type stringParentFieldType = GenericTypeHolder.class.getDeclaredField("stringParent")
-                .getGenericType();
-        final Type integerParentFieldType = GenericTypeHolder.class.getDeclaredField("integerParent")
-                .getGenericType();
+        final Type stringParentFieldType = GenericTypeHolder.class.getDeclaredField("stringParent").getGenericType();
+        final Type integerParentFieldType = GenericTypeHolder.class.getDeclaredField("integerParent").getGenericType();
         final Type foosFieldType = GenericTypeHolder.class.getDeclaredField("foos").getGenericType();
         final Type genericParentT = GenericParent.class.getTypeParameters()[0];
         assertEquals(GenericParent.class, TypeUtils.getRawType(stringParentFieldType, null));
-        assertEquals(GenericParent.class, TypeUtils.getRawType(integerParentFieldType,
-                        null));
+        assertEquals(GenericParent.class, TypeUtils.getRawType(integerParentFieldType, null));
         assertEquals(List.class, TypeUtils.getRawType(foosFieldType, null));
-        assertEquals(String.class, TypeUtils.getRawType(genericParentT,
-                StringParameterizedChild.class));
-        assertEquals(String.class, TypeUtils.getRawType(genericParentT,
-                stringParentFieldType));
-        assertEquals(Foo.class, TypeUtils.getRawType(Iterable.class.getTypeParameters()[0],
-                foosFieldType));
-        assertEquals(Foo.class, TypeUtils.getRawType(List.class.getTypeParameters()[0],
-                foosFieldType));
+        assertEquals(String.class, TypeUtils.getRawType(genericParentT, StringParameterizedChild.class));
+        assertEquals(String.class, TypeUtils.getRawType(genericParentT, stringParentFieldType));
+        assertEquals(Foo.class, TypeUtils.getRawType(Iterable.class.getTypeParameters()[0], foosFieldType));
+        assertEquals(Foo.class, TypeUtils.getRawType(List.class.getTypeParameters()[0], foosFieldType));
         assertNull(TypeUtils.getRawType(genericParentT, GenericParent.class));
-        assertEquals(GenericParent[].class, TypeUtils.getRawType(GenericTypeHolder.class
-                .getDeclaredField("barParents").getGenericType(), null));
+        assertEquals(GenericParent[].class, TypeUtils.getRawType(GenericTypeHolder.class.getDeclaredField("barParents").getGenericType(), null));
+    }
+
+    /**
+     * Tests https://issues.apache.org/jira/browse/LANG-1697
+     */
+    @Test
+    public void testGetRawType_LANG_1697() throws NoSuchFieldException {
+        assertEquals(int[].class, TypeUtils.getRawType(TypeUtils.genericArrayType(Integer.TYPE), Integer.TYPE));
+        // LANG-1697:
+        assertNull(TypeUtils.getRawType(TypeUtils.genericArrayType(TypeUtils.WILDCARD_ALL), null));
+        // TODO: Is this correct?
+        assertNull(TypeUtils.getRawType(TypeUtils.genericArrayType(TypeUtils.WILDCARD_ALL), TypeUtils.WILDCARD_ALL));
+        // TODO: Is this correct?
+        assertNull(TypeUtils.getRawType(TypeUtils.genericArrayType(TypeUtils.WILDCARD_ALL), Integer.TYPE));
     }
 
     @Test
@@ -750,7 +844,7 @@ public class TypeUtilsTest<B> {
         // int[] ina = ia;
         assertFalse(TypeUtils.isAssignable(Integer[].class, int[].class));
         final int[] ina = null;
-        Object[] oa;
+        final Object[] oa;
         // oa = ina;
         assertFalse(TypeUtils.isAssignable(int[].class, Object[].class));
         oa = new Integer[0];
@@ -801,6 +895,25 @@ public class TypeUtilsTest<B> {
                 () -> String.format("TypeUtils.isAssignable(%s, %s)", paramType, arrayType));
     }
 
+    @Test
+    public void testIsAssignableGenericArrayTypeToObject() {
+        final Class<Constructor> rawClass = Constructor.class;
+        final Class<Insets> typeArgClass = Insets.class;
+        // Builds a ParameterizedType for Constructor<Insets>
+        final ParameterizedType paramType = TypeUtils.parameterize(rawClass, typeArgClass);
+        assertEquals(rawClass, paramType.getRawType());
+        assertEquals(typeArgClass, paramType.getActualTypeArguments()[0]);
+
+        assertTrue(Object.class.isAssignableFrom(paramType.getClass()));
+        assertFalse(paramType.getClass().isAssignableFrom(Object.class));
+
+        final Type testType = Object.class;
+        assertTrue(TypeUtils.isAssignable(paramType, testType),
+                () -> String.format("TypeUtils.isAssignable(%s, %s)", paramType, testType));
+        assertFalse(TypeUtils.isAssignable(testType, paramType),
+                () -> String.format("TypeUtils.isAssignable(%s, %s)", testType, paramType));
+    }
+
     @Test
     public void testIsAssignableGenericArrayTypeToParameterizedType() {
         final Class<Constructor> rawClass = Constructor.class;
@@ -842,25 +955,6 @@ public class TypeUtilsTest<B> {
                 () -> String.format("TypeUtils.isAssignable(%s, %s)", testType, paramType));
     }
 
-    @Test
-    public void testIsAssignableGenericArrayTypeToObject() {
-        final Class<Constructor> rawClass = Constructor.class;
-        final Class<Insets> typeArgClass = Insets.class;
-        // Builds a ParameterizedType for Constructor<Insets>
-        final ParameterizedType paramType = TypeUtils.parameterize(rawClass, typeArgClass);
-        assertEquals(rawClass, paramType.getRawType());
-        assertEquals(typeArgClass, paramType.getActualTypeArguments()[0]);
-
-        assertTrue(Object.class.isAssignableFrom(paramType.getClass()));
-        assertFalse(paramType.getClass().isAssignableFrom(Object.class));
-
-        final Type testType = Object.class;
-        assertTrue(TypeUtils.isAssignable(paramType, testType),
-                () -> String.format("TypeUtils.isAssignable(%s, %s)", paramType, testType));
-        assertFalse(TypeUtils.isAssignable(testType, paramType),
-                () -> String.format("TypeUtils.isAssignable(%s, %s)", testType, paramType));
-    }
-
     @SuppressWarnings("boxing") // boxing is deliberate here
     @Test
     public void testIsInstance() throws SecurityException, NoSuchFieldException {
@@ -872,36 +966,6 @@ public class TypeUtilsTest<B> {
         assertFalse(TypeUtils.isInstance(1, uriComparableType));
     }
 
-    @Test
-    public void testLang1114() throws Exception {
-        final Type nonWildcardType = getClass().getDeclaredField("wildcardComparable").getGenericType();
-        final Type wildcardType = ((ParameterizedType) nonWildcardType).getActualTypeArguments()[0];
-
-        assertFalse(TypeUtils.equals(wildcardType, nonWildcardType));
-        assertFalse(TypeUtils.equals(nonWildcardType, wildcardType));
-    }
-
-    @Test
-    public void testLANG1190() throws Exception {
-        final Type fromType = ClassWithSuperClassWithGenericType.class.getDeclaredMethod("methodWithGenericReturnType").getGenericReturnType();
-        final Type failingToType = TypeUtils.wildcardType().withLowerBounds(ClassWithSuperClassWithGenericType.class).build();
-
-        assertTrue(TypeUtils.isAssignable(fromType, failingToType));
-    }
-
-    @Test
-    public void testLANG1348() throws Exception {
-        final Method method = Enum.class.getMethod("valueOf", Class.class, String.class);
-        assertEquals("T extends java.lang.Enum<T>", TypeUtils.toString(method.getGenericReturnType()));
-    }
-
-    @Test
-    public void testLang820() {
-        final Type[] typeArray = {String.class, String.class};
-        final Type[] expectedArray = {String.class};
-        assertArrayEquals(expectedArray, TypeUtils.normalizeUpperBounds(typeArray));
-    }
-
     @Test
     public void testLowerBoundedWildcardType() {
        final WildcardType lowerBounded = TypeUtils.wildcardType().withLowerBounds(java.sql.Date.class).build();
@@ -931,6 +995,18 @@ public class TypeUtilsTest<B> {
         assertEquals(TypeUtils.parameterize(ArrayList.class, String.class), unrolled);
     }
 
+    @Test
+    public void testParameterizeNullPointerException() {
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterize(null, Collections.emptyMap()));
+        final Map<TypeVariable<?>, Type> nullTypeVariableMap = null;
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterize(String.class, nullTypeVariableMap));
+    }
+
+    @Test
+    public void testParameterizeVarArgsNullPointerException() {
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterize(null));
+    }
+
     @Test
     public void testParameterizeWithOwner() throws Exception {
         final Type owner = TypeUtils.parameterize(TypeUtilsTest.class, String.class);
@@ -939,12 +1015,28 @@ public class TypeUtilsTest<B> {
     }
 
     @Test
-    public void testToLongString() {
-        assertEquals(getClass().getName() + ":B", TypeUtils.toLongString(getClass().getTypeParameters()[0]));
+    public void testParameterizeWithOwner3ArgsNullPointerException() {
+        final Type owner = TypeUtils.parameterize(TypeUtilsTest.class, String.class);
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterizeWithOwner(owner, null, String.class));
+        final Map<TypeVariable<?>, Type> nullTypeVariableMap = null;
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterizeWithOwner(owner, That.class, nullTypeVariableMap));
     }
 
     @Test
-    public void testToStringLang1311() {
+    public void testParameterizeWithOwnerVarArgsNullPointerException() {
+        final Type owner = TypeUtils.parameterize(TypeUtilsTest.class, String.class);
+        assertThrows(NullPointerException.class, () -> TypeUtils.parameterizeWithOwner(owner, null));
+    }
+
+    @Test
+    public void testToLongString() {
+        assertEquals(getClass().getName() + ":B", TypeUtils.toLongString(getClass().getTypeParameters()[0]));
+
+        assertThrows(NullPointerException.class, () -> TypeUtils.toLongString(null));
+    }
+
+    @Test
+    public void testToString_LANG_1311() {
         assertEquals("int[]", TypeUtils.toString(int[].class));
         assertEquals("java.lang.Integer[]", TypeUtils.toString(Integer[].class));
         final Field stringListField = FieldUtils.getDeclaredField(getClass(), "stringListArray");
@@ -964,6 +1056,8 @@ public class TypeUtilsTest<B> {
         typeVarAssigns.clear();
         typeVarAssigns.put(getClass().getMethod("stub3").getTypeParameters()[0], Integer.class);
         assertTrue(TypeUtils.typesSatisfyVariables(typeVarAssigns));
+
+        assertThrows(NullPointerException.class, () -> TypeUtils.typesSatisfyVariables(null));
     }
 
     @Test
@@ -974,6 +1068,11 @@ public class TypeUtilsTest<B> {
         assertArrayEquals(new Type[] { null }, TypeUtils.getImplicitLowerBounds(unbounded));
         assertEquals("?", TypeUtils.toString(unbounded));
         assertEquals("?", unbounded.toString());
+
+        assertThrows(NullPointerException.class,
+                () -> TypeUtils.getImplicitLowerBounds(null));
+        assertThrows(NullPointerException.class,
+                () -> TypeUtils.getImplicitUpperBounds(null));
     }
 
     @Test
