@@ -24,15 +24,19 @@ import static org.junit.jupiter.api.Assertions.assertAll;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotNull;
 import static org.junit.jupiter.api.Assertions.assertThrows;
+import static org.junit.jupiter.api.Assertions.assertTrue;
 import static org.junit.jupiter.api.DynamicTest.dynamicTest;
 
 import java.lang.reflect.UndeclaredThrowableException;
 import java.util.ArrayList;
 import java.util.Arrays;
+import java.util.Hashtable;
+import java.util.Iterator;
 import java.util.List;
 import java.util.stream.Collectors;
 import java.util.stream.Stream;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.apache.commons.lang3.function.Failable;
 import org.apache.commons.lang3.function.FailableConsumer;
 import org.apache.commons.lang3.function.FailablePredicate;
@@ -42,12 +46,15 @@ import org.junit.jupiter.api.TestFactory;
 import org.junit.jupiter.api.function.Executable;
 import org.xml.sax.SAXException;
 
-public class StreamsTest {
+/**
+ * Tests {@link Streams}.
+ */
+public class StreamsTest extends AbstractLangTest {
 
     protected <T extends Throwable> FailableConsumer<String, T> asIntConsumer(final T pThrowable) {
         return s -> {
-            final Integer i = Integer.valueOf(s);
-            if (i.intValue() == 4) {
+            final int i = Integer.parseInt(s);
+            if (i == 4) {
                 throw pThrowable;
             }
         };
@@ -72,36 +79,30 @@ public class StreamsTest {
     @TestFactory
     public Stream<DynamicTest> simpleStreamFilterFailing() {
         final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-        final List<Integer> output = Failable.stream(input).map(Integer::valueOf).filter(asIntPredicate(null))
-            .collect(Collectors.toList());
+        final List<Integer> output = Failable.stream(input).map(Integer::valueOf).filter(asIntPredicate(null)).collect(Collectors.toList());
         assertEvenNumbers(output);
 
         return Stream.of(
 
             dynamicTest("IllegalArgumentException", () -> {
                 final IllegalArgumentException iae = new IllegalArgumentException("Invalid argument: " + 5);
-                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf)
-                    .filter(asIntPredicate(iae)).collect(Collectors.toList());
+                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf).filter(asIntPredicate(iae)).collect(Collectors.toList());
                 final IllegalArgumentException thrown = assertThrows(IllegalArgumentException.class, testMethod);
                 assertThat(thrown.getMessage(), is(equalTo("Invalid argument: " + 5)));
             }),
 
             dynamicTest("OutOfMemoryError", () -> {
                 final OutOfMemoryError oome = new OutOfMemoryError();
-                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf)
-                    .filter(asIntPredicate(oome)).collect(Collectors.toList());
+                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf).filter(asIntPredicate(oome)).collect(Collectors.toList());
                 final OutOfMemoryError thrown = assertThrows(OutOfMemoryError.class, testMethod);
                 assertThat(thrown.getMessage(), is(nullValue()));
             }),
 
             dynamicTest("SAXException", () -> {
                 final SAXException se = new SAXException();
-                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf)
-                    .filter(asIntPredicate(se)).collect(Collectors.toList());
-                final UndeclaredThrowableException thrown = assertThrows(UndeclaredThrowableException.class,
-                    testMethod);
-                assertAll(() -> assertThat(thrown.getMessage(), is(nullValue())),
-                    () -> assertThat(thrown.getCause(), is(equalTo(se))));
+                final Executable testMethod = () -> Failable.stream(input).map(Integer::valueOf).filter(asIntPredicate(se)).collect(Collectors.toList());
+                final UndeclaredThrowableException thrown = assertThrows(UndeclaredThrowableException.class, testMethod);
+                assertAll(() -> assertThat(thrown.getMessage(), is(nullValue())), () -> assertThat(thrown.getCause(), is(equalTo(se))));
             }));
     }
 
@@ -128,18 +129,92 @@ public class StreamsTest {
             dynamicTest("SAXException", () -> {
                 final SAXException se = new SAXException();
                 final Executable seTestMethod = () -> Failable.stream(input).forEach(asIntConsumer(se));
-                final UndeclaredThrowableException seThrown = assertThrows(UndeclaredThrowableException.class,
-                    seTestMethod);
-                assertAll(() -> assertThat(seThrown.getMessage(), is(nullValue())),
-                    () -> assertThat(seThrown.getCause(), is(equalTo(se))));
+                final UndeclaredThrowableException seThrown = assertThrows(UndeclaredThrowableException.class, seTestMethod);
+                assertAll(() -> assertThat(seThrown.getMessage(), is(nullValue())), () -> assertThat(seThrown.getCause(), is(equalTo(se))));
             }));
     }
 
+    @Test
+    public void testInstanceOfStream() {
+        assertEquals(2, Streams.instancesOf(String.class, Arrays.asList("A", "B")).collect(Collectors.toList()).size());
+        assertEquals(2, Streams.instancesOf(String.class, Arrays.asList(null, "A", null, "B", null)).collect(Collectors.toList()).size());
+        assertEquals(0, Streams.instancesOf(String.class, Arrays.asList(null, null)).collect(Collectors.toList()).size());
+        //
+        final List<Object> objects = Arrays.asList("A", "B");
+        assertEquals(2, Streams.instancesOf(String.class, objects).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testNullSafeStreamNotNull() {
+        assertEquals(2, Streams.nonNull(Arrays.asList("A", "B")).collect(Collectors.toList()).size());
+        assertEquals(2, Streams.nonNull(Arrays.asList(null, "A", null, "B", null)).collect(Collectors.toList()).size());
+        assertEquals(0, Streams.nonNull(Arrays.asList(null, null)).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testNullSafeStreamNull() {
+        final List<String> input = null;
+        assertEquals(0, Streams.nonNull(input).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfArray() {
+        assertEquals(0, Streams.of((Object[]) null).count());
+        assertEquals(1, Streams.of("foo").count());
+        assertEquals(2, Streams.of("foo", "bar").count());
+    }
+
+    @Test
+    public void testOfCollectionNotNull() {
+        assertEquals(2, Streams.of(Arrays.asList("A", "B")).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfCollectionNull() {
+        final List<String> input = null;
+        assertEquals(0, Streams.of(input).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfEnumeration() {
+        final Hashtable<String, Integer> table = new Hashtable<>();
+        assertEquals(0, Streams.of(table.elements()).count());
+        table.put("One", 1);
+        assertEquals(1, Streams.of(table.elements()).count());
+        table.put("Two", 2);
+        assertEquals(2, Streams.of(table.elements()).count());
+        final List<String> collect = Streams.of(table.keys()).collect(Collectors.toList());
+        assertTrue(collect.contains("One"));
+        assertTrue(collect.contains("Two"));
+        assertEquals(2, collect.size());
+    }
+
+    @Test
+    public void testOfIterableNotNull() {
+        assertEquals(2, Streams.of((Iterable<String>) Arrays.asList("A", "B")).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfIterableNull() {
+        final Iterable<String> input = null;
+        assertEquals(0, Streams.of(input).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfIteratorNotNull() {
+        assertEquals(2, Streams.of(Arrays.asList("A", "B").iterator()).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testOfIteratorNull() {
+        final Iterator<String> input = null;
+        assertEquals(0, Streams.of(input).collect(Collectors.toList()).size());
+    }
+
     @Test
     public void testSimpleStreamFilter() {
         final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
-        final List<Integer> output = Failable.stream(input).map(Integer::valueOf).filter(i -> (i.intValue() % 2 == 0))
-            .collect(Collectors.toList());
+        final List<Integer> output = Failable.stream(input).map(Integer::valueOf).filter(i -> (i.intValue() % 2 == 0)).collect(Collectors.toList());
         assertEvenNumbers(output);
     }
 
@@ -172,6 +247,18 @@ public class StreamsTest {
         assertEquals("For input string: \"4 \"", thrown.getMessage());
     }
 
+    @Test
+    public void testStreamCollection() {
+        final List<String> input = Arrays.asList("1", "2", "3", "4", "5", "6");
+        assertEquals(6, Streams.stream(input).collect(Collectors.toList()).size());
+    }
+
+    @Test
+    public void testStreamCollectionNull() {
+        final List<String> input = null;
+        assertEquals(0, Streams.stream(input).collect(Collectors.toList()).size());
+    }
+
     @Test
     public void testToArray() {
         final String[] array = Arrays.asList("2", "3", "1").stream().collect(Streams.toArray(String.class));
