@@ -26,6 +26,9 @@ import java.text.FieldPosition;
 import java.text.Format;
 import java.text.ParsePosition;
 import java.text.SimpleDateFormat;
+import java.time.Instant;
+import java.time.LocalDate;
+import java.time.ZoneId;
 import java.util.Date;
 import java.util.Locale;
 import java.util.TimeZone;
@@ -35,6 +38,7 @@ import java.util.concurrent.TimeUnit;
 import java.util.concurrent.atomic.AtomicInteger;
 import java.util.concurrent.atomic.AtomicLongArray;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.junit.jupiter.api.Test;
 import org.junitpioneer.jupiter.DefaultLocale;
 import org.junitpioneer.jupiter.DefaultTimeZone;
@@ -44,11 +48,14 @@ import org.junitpioneer.jupiter.DefaultTimeZone;
  *
  * @since 2.0
  */
-public class FastDateFormatTest {
+public class FastDateFormatTest extends AbstractLangTest {
     private static final int NTHREADS = 10;
 
     private static final int NROUNDS = 10000;
 
+    final Locale FINNISH = Locale.forLanguageTag("fi");
+    final Locale HUNGARIAN = Locale.forLanguageTag("hu");
+
     private AtomicLongArray measureTime(final Format printer, final Format parser) throws InterruptedException {
         final ExecutorService pool = Executors.newFixedThreadPool(NTHREADS);
         final AtomicInteger failures = new AtomicInteger(0);
@@ -275,14 +282,14 @@ public class FastDateFormatTest {
             public StringBuffer format(final Object obj,
                     final StringBuffer toAppendTo,
                     final FieldPosition fieldPosition) {
-                synchronized(this) {
+                synchronized (this) {
                     return inner.format(obj, toAppendTo, fieldPosition);
                 }
             }
 
             @Override
             public Object parseObject(final String source, final ParsePosition pos) {
-                synchronized(this) {
+                synchronized (this) {
                     return inner.parseObject(source, pos);
                 }
             }
@@ -296,6 +303,38 @@ public class FastDateFormatTest {
         //System.out.println(">>FastDateFormatTest: FastDateParser:"+fdfTime.get(1)+"  SimpleDateFormat:"+sdfTime.get(1));
     }
 
+    @Test
+    public void testStandaloneLongMonthForm() {
+        final TimeZone utc = FastTimeZone.getGmtTimeZone();
+        final Instant testInstant = LocalDate.of(1970, 9, 15).atStartOfDay(ZoneId.of("UTC")).toInstant();
+        final Date date = Date.from(testInstant);
+
+        String dateAsString = FastDateFormat.getInstance("yyyy-LLLL-dd", utc, Locale.GERMAN).format(date);
+        assertEquals("1970-September-15", dateAsString);
+
+        dateAsString = FastDateFormat.getInstance("yyyy-LLLL-dd", utc, FINNISH).format(date);
+        assertEquals("1970-syyskuu-15", dateAsString);
+
+        dateAsString = FastDateFormat.getInstance("yyyy-LLLL-dd", utc, HUNGARIAN).format(date);
+        assertEquals("1970-szeptember-15", dateAsString);
+    }
+
+    @Test
+    public void testStandaloneShortMonthForm() {
+        final TimeZone utc = FastTimeZone.getGmtTimeZone();
+        final Instant testInstant = LocalDate.of(1970, 9, 15).atStartOfDay(ZoneId.of("UTC")).toInstant();
+        final Date date = Date.from(testInstant);
+
+        String dateAsString = FastDateFormat.getInstance("yyyy-LLL-dd", utc, Locale.GERMAN).format(date);
+        assertEquals("1970-Sep-15", dateAsString);
+
+        dateAsString = FastDateFormat.getInstance("yyyy-LLL-dd", utc, FINNISH).format(date);
+        assertEquals("1970-syys-15", dateAsString);
+
+        dateAsString = FastDateFormat.getInstance("yyyy-LLL-dd", utc, HUNGARIAN).format(date);
+        assertEquals("1970-szept.-15", dateAsString);
+    }
+
     @Test
     public void testTimeDateDefaults() {
         assertEquals(FastDateFormat.getDateTimeInstance(FastDateFormat.LONG, FastDateFormat.MEDIUM, Locale.CANADA),
