@@ -30,6 +30,7 @@ import java.util.GregorianCalendar;
 import java.util.Locale;
 import java.util.TimeZone;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.apache.commons.lang3.SerializationUtils;
 import org.junit.jupiter.api.Test;
 import org.junitpioneer.jupiter.DefaultLocale;
@@ -40,10 +41,10 @@ import org.junitpioneer.jupiter.DefaultTimeZone;
  *
  * @since 3.0
  */
-public class FastDatePrinterTest {
+public class FastDatePrinterTest extends AbstractLangTest {
 
     private enum Expected1806 {
-        India(INDIA, "+05", "+0530", "+05:30"), Greenwich(GMT, "Z", "Z", "Z"), NewYork(
+        India(INDIA, "+05", "+0530", "+05:30"), Greenwich(TimeZones.GMT, "Z", "Z", "Z"), NewYork(
                 NEW_YORK, "-05", "-0500", "-05:00");
 
         final TimeZone zone;
@@ -60,7 +61,6 @@ public class FastDatePrinterTest {
     }
     private static final String YYYY_MM_DD = "yyyy/MM/dd";
     private static final TimeZone NEW_YORK = TimeZone.getTimeZone("America/New_York");
-    private static final TimeZone GMT = TimeZone.getTimeZone("GMT");
     private static final TimeZone INDIA = TimeZone.getTimeZone("Asia/Calcutta");
 
     private static final Locale SWEDEN = new Locale("sv", "SE");
@@ -78,7 +78,7 @@ public class FastDatePrinterTest {
     }
 
     private DatePrinter getDateInstance(final int dateStyle, final Locale locale) {
-        return getInstance(FormatCache.getPatternForStyle(Integer.valueOf(dateStyle), null, locale), TimeZone.getDefault(), Locale.getDefault());
+        return getInstance(AbstractFormatCache.getPatternForStyle(Integer.valueOf(dateStyle), null, locale), TimeZone.getDefault(), Locale.getDefault());
     }
 
     DatePrinter getInstance(final String format) {
@@ -126,7 +126,7 @@ public class FastDatePrinterTest {
 
     @Test
     public void testAppendableOptions() {
-        final DatePrinter format = getInstance("yyyy-MM-dd HH:mm:ss.SSS Z", TimeZone.getTimeZone("GMT"));
+        final DatePrinter format = getInstance("yyyy-MM-dd HH:mm:ss.SSS Z", TimeZones.GMT);
         final Calendar calendar = Calendar.getInstance();
         final StringBuilder sb = new StringBuilder();
         final String expected = format.format(calendar, sb).toString();
@@ -205,13 +205,13 @@ public class FastDatePrinterTest {
         assertEquals("-04:00", fdf.format(cal2));
         assertEquals("-04:00", fdf.format(millis2));
 
-        final String pattern = "GGGG GGG GG G yyyy yyy yy y MMMM MMM MM M" +
+        final String pattern = "GGGG GGG GG G yyyy yyy yy y MMMM MMM MM M LLLL LLL LL L" +
                 " dddd ddd dd d DDDD DDD DD D EEEE EEE EE E aaaa aaa aa a zzzz zzz zz z";
         fdf = getInstance(pattern);
         sdf = new SimpleDateFormat(pattern);
         // SDF bug fix starting with Java 7
-        assertEquals(sdf.format(date1).replaceAll("2003 03 03 03", "2003 2003 03 2003"), fdf.format(date1));
-        assertEquals(sdf.format(date2).replaceAll("2003 03 03 03", "2003 2003 03 2003"), fdf.format(date2));
+        assertEquals(sdf.format(date1).replace("2003 03 03 03", "2003 2003 03 2003"), fdf.format(date1));
+        assertEquals(sdf.format(date2).replace("2003 03 03 03", "2003 2003 03 2003"), fdf.format(date2));
     }
 
     @Test
@@ -262,7 +262,7 @@ public class FastDatePrinterTest {
         cal.clear();
         cal.set(2009, Calendar.OCTOBER, 16, 8, 42, 16);
 
-        final DatePrinter format = getInstance("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'", TimeZone.getTimeZone("GMT"));
+        final DatePrinter format = getInstance("yyyy-MM-dd'T'HH:mm:ss.SSS'Z'", TimeZones.GMT);
         assertEquals("2009-10-16T16:42:16.000Z", format.format(cal.getTime()), "dateTime");
         assertEquals("2009-10-16T16:42:16.000Z", format.format(cal), "dateTime");
     }
@@ -387,7 +387,7 @@ public class FastDatePrinterTest {
     @SuppressWarnings("deprecation")
     @Test
     public void testStringBufferOptions() {
-        final DatePrinter format = getInstance("yyyy-MM-dd HH:mm:ss.SSS Z", TimeZone.getTimeZone("GMT"));
+        final DatePrinter format = getInstance("yyyy-MM-dd HH:mm:ss.SSS Z", TimeZones.GMT);
         final Calendar calendar = Calendar.getInstance();
         final StringBuffer sb = new StringBuffer();
         final String expected = format.format(calendar, sb, new FieldPosition(0)).toString();
