@@ -19,17 +19,19 @@ package org.apache.commons.lang3.tuple;
 import static org.junit.jupiter.api.Assertions.assertEquals;
 import static org.junit.jupiter.api.Assertions.assertNotEquals;
 import static org.junit.jupiter.api.Assertions.assertNull;
+import static org.junit.jupiter.api.Assertions.assertThrows;
 
 import java.util.HashMap;
 import java.util.Map.Entry;
 
+import org.apache.commons.lang3.AbstractLangTest;
 import org.apache.commons.lang3.SerializationUtils;
 import org.junit.jupiter.api.Test;
 
 /**
  * Test the MutablePair class.
  */
-public class MutablePairTest {
+public class MutablePairTest extends AbstractLangTest {
 
     @Test
     public void testBasic() {
@@ -102,6 +104,16 @@ public class MutablePairTest {
         assertEquals("bar", pair.getRight());
     }
 
+    @Test
+    public void testOfNonNull() {
+        assertThrows(NullPointerException.class, () -> MutablePair.ofNonNull(null, null));
+        assertThrows(NullPointerException.class, () -> MutablePair.ofNonNull(null, "x"));
+        assertThrows(NullPointerException.class, () -> MutablePair.ofNonNull("x", null));
+        final MutablePair<String, String> pair = MutablePair.ofNonNull("x", "y");
+        assertEquals("x", pair.left);
+        assertEquals("y", pair.right);
+    }
+
     @Test
     public void testPairOfMapEntry() {
         final HashMap<Integer, String> map = new HashMap<>();
